@@ -37,12 +37,14 @@
 
 #include "gdal/cpl_csv.h"
 #include "ogr_s57.h"
+#include "s52s57.h"
 #include "chartbase.h"
 
 #include <string.h>
 #include <stdint.h>
 #include <vector>
 #include <mutex>
+#include <unordered_map>
 
 WX_DEFINE_ARRAY_PTR(float *, SENCFloatPtrArray);
 
@@ -314,8 +316,6 @@ typedef std::vector<S57Obj *> S57ObjVector;
 typedef std::vector<VE_Element *> VE_ElementVector;
 typedef std::vector<VC_Element *> VC_ElementVector;
 
-WX_DECLARE_HASH_MAP(int, int, wxIntegerHash, wxIntegerEqual, VectorHelperHash);
-
 //--------------------------------------------------------------------------
 //      Osenc_instream definition
 //--------------------------------------------------------------------------
@@ -539,7 +539,7 @@ private:
 
   double m_ref_lat,
       m_ref_lon;  // Common reference point, derived from FullExtent
-  VectorHelperHash m_vector_helper_hash;
+  std::unordered_map<int, int> m_vector_helper_hash;
   double m_LOD_meters;
   S57ClassRegistrar *m_poRegistrar;
   wxArrayString m_tmpup_array;
