@@ -38,7 +38,7 @@
 #define PLUGIN_VERSION_MINOR 2
 
 #define MY_API_VERSION_MAJOR 1
-#define MY_API_VERSION_MINOR 6
+#define MY_API_VERSION_MINOR 8
 
 #include <wx/notebook.h>
 #include <wx/fileconf.h>
@@ -64,6 +64,7 @@
 #include "rudder_angle.h"
 #include "gps.h"
 #include "depth.h"
+#include "altitude.h"
 #include "clock.h"
 #include "wind_history.h"
 #include "baro_history.h"
@@ -78,12 +79,12 @@ class DashboardWindow;
 class DashboardWindowContainer;
 class DashboardInstrumentContainer;
 
-#define DASHBOARD_TOOL_POSITION \
-  -1  // Request default positioning of toolbar tool
-
-#define gps_watchdog_timeout_ticks 10
-#define no_nav_watchdog_timeout_ticks \
-  40  // SignalK motor & environ instr defaults 30 sec
+// Request default positioning of toolbar tool
+#define DASHBOARD_TOOL_POSITION -1
+// Set watchdog to comply with OCPN WD.
+#define gps_watchdog_timeout_ticks GetGlobalWatchdogTimoutSeconds()
+// SignalK motor & environ instr defaults 30 sec update frequency
+#define no_nav_watchdog_timeout_ticks 40
 #define GEODESIC_RAD2DEG(r) ((r) * (180.0 / M_PI))
 #define MS2KNOTS(r) ((r) * (1.9438444924406))
 #define KELVIN2C(r) ((r) - (273.15))
@@ -147,7 +148,7 @@ WX_DEFINE_ARRAY(DashboardInstrumentContainer *, wxArrayOfInstrument);
 //    The PlugIn Class Definition
 //----------------------------------------------------------------------------------------------------------
 
-class dashboard_pi : public wxTimer, opencpn_plugin_16 {
+class dashboard_pi : public wxTimer, opencpn_plugin_18 {
 public:
   dashboard_pi(void *ppimgr);
   ~dashboard_pi(void);
@@ -169,7 +170,7 @@ public:
 
   //    The optional method overrides
   void SetNMEASentence(wxString &sentence);
-  void SetPositionFix(PlugIn_Position_Fix &pfix);
+  void SetPositionFixEx(PlugIn_Position_Fix_Ex& pfix);
   void SetCursorLatLon(double lat, double lon);
   int GetToolbarToolCount(void);
   void OnToolbarToolCallback(int id);
@@ -199,6 +200,35 @@ private:
   void ParseSignalK(wxString &msg);
   void handleSKUpdate(wxJSONValue &update);
   void updateSKItem(wxJSONValue &item, wxString &talker, wxString &sfixtime);
+
+  void HandleN2K_127245(ObservedEvt ev);
+  void HandleN2K_127257(ObservedEvt ev);
+  void HandleN2K_128259(ObservedEvt ev);
+  void HandleN2K_128267(ObservedEvt ev);
+  void HandleN2K_128275(ObservedEvt ev);
+  void HandleN2K_129029(ObservedEvt ev);
+  void HandleN2K_129540(ObservedEvt ev);
+  void HandleN2K_130306(ObservedEvt ev);
+  void HandleN2K_130310(ObservedEvt ev);
+  std::shared_ptr<ObservableListener> listener_127245;
+  std::shared_ptr<ObservableListener> listener_127257;
+  std::shared_ptr<ObservableListener> listener_128259;
+  std::shared_ptr<ObservableListener> listener_128267;
+  std::shared_ptr<ObservableListener> listener_128275;
+  std::shared_ptr<ObservableListener> listener_129029;
+  std::shared_ptr<ObservableListener> listener_129540;
+  std::shared_ptr<ObservableListener> listener_130306;
+  std::shared_ptr<ObservableListener> listener_130310;
+
+
+  std::string prio127245;
+  std::string prio127257;
+  std::string prio128259;
+  std::string prio128267;
+  std::string prio129029;
+  std::string prioN2kPGNsat;
+  std::string prio130306;
+
   wxString m_self;
 
   wxFileConfig *m_pconfig;
@@ -215,7 +245,7 @@ private:
   short mPriSTW, mPriWTP, mPriATMP, mPriWDN, mPriSatStatus;
   // Prio: Pos from O, SK gnss.satellites, GGA sats in use, SK gnss
   // satellitesinView, GSV sats in view
-  short mPriSatUsed;
+  short mPriSatUsed, mPriAlt, mPriRSA, mPriPitchRoll;
   double mVar;
   // FFU
   int mSatsInView;
@@ -241,6 +271,9 @@ private:
   int mMDA_Watchdog;
   int mPITCH_Watchdog;
   int mHEEL_Watchdog;
+  int mALT_Watchdog;
+  int mLOG_Watchdog;
+  int mTrLOG_Watchdog;
 
   iirfilter mSOGFilter;
   iirfilter mCOGFilter;
