@@ -25,29 +25,29 @@
  ***************************************************************************
  */
 
+
+#include <wx/wxprec.h>
+
+#ifndef WX_PRECOMP
+#include <wx/wx.h>
+#endif  // precompiled headers
+
 #include "gps.h"
 #include "wx28compat.h"
 
-// For compilers that support precompilation, includes "wx/wx.h".
-#include <wx/wxprec.h>
-
 #ifdef __BORLANDC__
 #pragma hdrstop
 #endif
 
-// for all others, include the necessary headers (this file is usually all you
-// need because it includes almost all "standard" wxWidgets headers)
-#ifndef WX_PRECOMP
-#include <wx/wx.h>
-#endif
-
 // Required deg2rad
 #include "dial.h"
 
 DashboardInstrument_GPS::DashboardInstrument_GPS(wxWindow* parent,
                                                  wxWindowID id, wxString title)
     : DashboardInstrument(parent, id, title, OCPN_DBP_STC_GPS) {
-  m_refDim = GetCharHeight() * 90 / 100;
+  m_refDim = GetCharHeight() * 80 / 100;
+  m_refDim *= OCPN_GetWinDIPScaleFactor() < 1.0 ?
+              2.0 * OCPN_GetWinDIPScaleFactor() : 1.0; //1.5
 
   m_cx = 35;
   m_cy = m_refDim * 35 / 10;
@@ -101,11 +101,11 @@ void DashboardInstrument_GPS::SetSatInfo(int cnt, int seq, wxString talk,
   if (talkerID != wxEmptyString) {
     /* Switch view between the six GNSS system
        mentioned in NMEA0183, when available.
-       Show each system for 30 seconds.
+       Show each system for 20 seconds.
        Time to shift now? */
     wxDateTime now = wxDateTime::Now();
     wxTimeSpan sinceLastShift = now - m_lastShift;
-    if (sinceLastShift.GetSeconds() > 30) {
+    if (sinceLastShift.GetSeconds() > 20) {
       b_shift = true;
       m_lastShift = now;
     }
@@ -149,7 +149,7 @@ void DashboardInstrument_GPS::SetSatInfo(int cnt, int seq, wxString talk,
       if (m_MaxSatCount > m_SatCount) return;
       else m_MaxSatCount = m_SatCount;
       s_gTalker = wxString::Format(_T("Galileo\n%d"), m_SatCount);
-    } else if (talkerID == _T("GB")) {  // BeiDou  BDS
+    } else if (talkerID == _T("GB") || talkerID == _T("BD")) {  // BeiDou  BDS
       m_Gtime[4] = now;
       if (m_iMaster != 4) return;
       // See "GP" above
@@ -296,11 +296,14 @@ void DashboardInstrument_GPS::DrawBackground(wxGCDC* dc) {
   tdc.SetTextForeground(cl);
 
   int pitch = m_refDim;
-  int offset = m_refDim * 12 / 100;
+  int offset = m_refDim * 15 / 100;
   for (int idx = 0; idx < 12; idx++) {
-    if (m_SatInfo[idx].SatNumber)
-      tdc.DrawText(wxString::Format(_T("%02d"), m_SatInfo[idx].SatNumber),
-                   idx * pitch + offset, 0);
+    if (m_SatInfo[idx].SatNumber) {
+      wxString satno = wxString::Format(_T("%02d"), m_SatInfo[idx].SatNumber);
+      //Avoid three digit sat-number here. Especially for BeiDou(GB/BD)
+      satno = satno.Right(2);
+      tdc.DrawText(satno, idx * pitch + offset, 0);
+    }
     else
       tdc.DrawText(" -", idx * pitch + offset, 0);
   }
@@ -332,7 +335,7 @@ void DashboardInstrument_GPS::DrawForeground(wxGCDC* dc) {
   int m_scaleDelta = m_refDim / 2;
   int m_scaleBase = (m_radius * 2) + (2 * m_refDim);
   int pitch = m_refDim;
-  int offset = m_refDim * 25 / 100;
+  int offset = m_refDim * 12 / 100;
 
   for (int idx = 0; idx < 12; idx++) {
     if (m_SatInfo[idx].SignalToNoiseRatio) {
@@ -363,18 +366,14 @@ void DashboardInstrument_GPS::DrawForeground(wxGCDC* dc) {
       tdc.DrawText(label, 0, 0);
       tdc.SelectObject(wxNullBitmap);
 
-      int posx =
-          m_cx +
-          m_radius *
+      int posx = m_cx + m_radius *
               cos(deg2rad(m_SatInfo[idx].AzimuthDegreesTrue - ANGLE_OFFSET)) *
               sin(deg2rad(ANGLE_OFFSET - m_SatInfo[idx].ElevationDegrees)) -
-          width / 2;
-      int posy =
-          m_cy +
-          m_radius *
+              width / 2.0;
+      int posy = m_cy + m_radius *
               sin(deg2rad(m_SatInfo[idx].AzimuthDegreesTrue - ANGLE_OFFSET)) *
               sin(deg2rad(ANGLE_OFFSET - m_SatInfo[idx].ElevationDegrees)) -
-          height / 2;
+              height / 2.0;
       dc->DrawBitmap(tbm, posx, posy, false);
     }
   }
