@@ -25,22 +25,20 @@
  ***************************************************************************
  */
 
+
+#include <wx/wxprec.h>
+
+#ifndef WX_PRECOMP
+#include <wx/wx.h>
+#endif  // precompiled headers
+
 #include "wind_history.h"
 #include "wx28compat.h"
 
-// For compilers that support precompilation, includes "wx/wx.h".
-#include <wx/wxprec.h>
-
 #ifdef __BORLANDC__
 #pragma hdrstop
 #endif
 
-// for all others, include the necessary headers (this file is usually all you
-// need because it includes almost all "standard" wxWidgets headers)
-#ifndef WX_PRECOMP
-#include <wx/wx.h>
-#endif
-
 //************************************************************************************************************************
 // History of wind direction
 //************************************************************************************************************************
@@ -54,15 +52,20 @@ DashboardInstrument_WindDirHistory::DashboardInstrument_WindDirHistory(
   m_WindDir = -1;
   m_WindDirRange = 90;
   m_MaxWindSpd = 0;
-  m_WindSpeedUnit = _("--");
+  m_WindSpeedUnit = _("-");
   m_TotalMaxWindSpd = 0;
   m_WindSpd = 0;
-  m_TopLineHeight = 30;
+  // Set top line height to leave space for wind data
+  wxClientDC dc(this);
+  int w, h;
+  dc.GetTextExtent("TWS----", &w, &h, 0, 0, g_pFontData);
+  m_TopLineHeight = wxMax(30, h);
   m_SpdRecCnt = 0;
   m_DirRecCnt = 0;
   m_SpdStartVal = -1;
   m_DirStartVal = -1;
   m_IsRunning = false;
+  m_SetNewData = 0;
   m_SampleCount = 0;
   m_LeftLegend = 3;
   m_RightLegend = 3;
@@ -92,109 +95,128 @@ wxSize DashboardInstrument_WindDirHistory::GetSize(int orient, wxSize hint) {
                   wxMax(m_TitleHeight + 140, hint.y));
   }
 }
+
 void DashboardInstrument_WindDirHistory::SetData(DASH_CAP st, double data,
                                                  wxString unit) {
   if (st == OCPN_DBP_STC_TWD || st == OCPN_DBP_STC_TWS) {
-    if (st == OCPN_DBP_STC_TWD) {
-      m_WindDir = data;
-      if (m_DirRecCnt <= 5) {
-        m_DirStartVal += data;
-        m_DirRecCnt++;
-      }
-    }
-    if (st == OCPN_DBP_STC_TWS && (std::isnan(data) || data < 200.0)) {
-      m_WindSpd = data;
-      // if unit changes, reset everything ...
-      if (unit != m_WindSpeedUnit && m_WindSpeedUnit != _("--")) {
-        m_MaxWindDir = -1;
-        m_WindDir = -1;
-        m_WindDirRange = 90;
-        m_MaxWindSpd = 0;
-        m_TotalMaxWindSpd = 0;
-        m_WindSpd = 0;
-        m_SpdRecCnt = 0;
-        m_DirRecCnt = 0;
-        m_SpdStartVal = -1;
-        m_DirStartVal = -1;
-        m_IsRunning = false;
-        m_SampleCount = 0;
-        m_LeftLegend = 3;
-        m_RightLegend = 3;
-        for (int idx = 0; idx < WIND_RECORD_COUNT; idx++) {
-          m_ArrayWindDirHistory[idx] = -1;
-          m_ArrayWindSpdHistory[idx] = -1;
-          m_ExpSmoothArrayWindSpd[idx] = -1;
-          m_ExpSmoothArrayWindDir[idx] = -1;
-          m_ArrayRecTime[idx] = wxDateTime::Now().GetTm();
-          m_ArrayRecTime[idx].year = 999;
+    if (m_SetNewData < 1) {
+      if (st == OCPN_DBP_STC_TWD) {
+        if (std::isnan(data)) {
+          // This NAN is from the one Watchdog used to reset wind history graph
+          ResetData();
+          m_WindSpd = m_WindDir = NAN;
+        }
+        else {
+          m_WindDir = data;
+          if (m_DirRecCnt <= 5) {
+            m_DirStartVal += data;
+            m_DirRecCnt++;
+          }
         }
       }
-      m_WindSpeedUnit = unit;
-      if (m_SpdRecCnt <= 5) {
-        m_SpdStartVal += data;
-        m_SpdRecCnt++;
+      if (st == OCPN_DBP_STC_TWS && !std::isnan(data) && data < 200.0) {
+        m_WindSpd = data;
+        // if unit changes, reset everything ...
+        if (unit != m_WindSpeedUnit && m_WindSpeedUnit != _("-")) {
+          ResetData();
+        }
+        m_WindSpeedUnit = unit;
+        if (m_SpdRecCnt <= 5) {
+          m_SpdStartVal += data;
+          m_SpdRecCnt++;
+        }
       }
-    }
-    if (m_SpdRecCnt == 5 && m_DirRecCnt == 5) {
-      m_WindSpd = m_SpdStartVal / 5;
-      m_WindDir = m_DirStartVal / 5;
-      m_oldDirVal = m_WindDir;  // make sure we don't get a diff > or <180 in
-                                // the initial run
-    }
-    // start working after we collected 5 records each, as start values for the
-    // smoothed curves
-    if (m_SpdRecCnt > 5 && m_DirRecCnt > 5) {
-      m_IsRunning = true;
-      m_SampleCount = m_SampleCount < WIND_RECORD_COUNT ? m_SampleCount + 1
-                                                        : WIND_RECORD_COUNT;
-      m_MaxWindDir = 0;
-      m_MinWindDir = 360;
-      m_MaxWindSpd = 0;
-      // data shifting
-      for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
-        if (WIND_RECORD_COUNT - m_SampleCount <= idx)
-          m_MinWindDir = wxMin(m_ArrayWindDirHistory[idx], m_MinWindDir);
-        m_MaxWindDir = wxMax(m_ArrayWindDirHistory[idx - 1], m_MaxWindDir);
-        m_MaxWindSpd = wxMax(m_ArrayWindSpdHistory[idx - 1], m_MaxWindSpd);
-        m_ArrayWindDirHistory[idx - 1] = m_ArrayWindDirHistory[idx];
-        m_ArrayWindSpdHistory[idx - 1] = m_ArrayWindSpdHistory[idx];
-        m_ExpSmoothArrayWindSpd[idx - 1] = m_ExpSmoothArrayWindSpd[idx];
-        m_ExpSmoothArrayWindDir[idx - 1] = m_ExpSmoothArrayWindDir[idx];
-        m_ArrayRecTime[idx - 1] = m_ArrayRecTime[idx];
+      if (m_SpdRecCnt == 5 && m_DirRecCnt == 5) {
+        m_WindSpd = m_SpdStartVal / 5;
+        m_WindDir = m_DirStartVal / 5;
+        m_oldDirVal = m_WindDir;  // make sure we don't get a diff > or <180 in
+        // the initial run
       }
-      double diff = m_WindDir - m_oldDirVal;
-      if (diff < -270) {
-        m_WindDir += 360;
-      } else if (diff > 270) {
-        m_WindDir -= 360;
-      }
-      m_ArrayWindDirHistory[WIND_RECORD_COUNT - 1] = m_WindDir;
-      m_ArrayWindSpdHistory[WIND_RECORD_COUNT - 1] = m_WindSpd;
-      if (m_SampleCount < 2) {
-        m_ArrayWindSpdHistory[WIND_RECORD_COUNT - 2] = m_WindSpd;
-        m_ExpSmoothArrayWindSpd[WIND_RECORD_COUNT - 2] = m_WindSpd;
-        m_ArrayWindDirHistory[WIND_RECORD_COUNT - 2] = m_WindDir;
-        m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 2] = m_WindDir;
-      }
-      m_ExpSmoothArrayWindSpd[WIND_RECORD_COUNT - 1] =
+      // start working after we collected 5 records each, as start values for the
+      // smoothed curves
+      if (m_SpdRecCnt > 5 && m_DirRecCnt > 5) {
+        m_IsRunning = true;
+        m_SampleCount = m_SampleCount < WIND_RECORD_COUNT ? m_SampleCount + 1
+          : WIND_RECORD_COUNT;
+        m_MaxWindDir = 0;
+        m_MinWindDir = 360;
+        m_MaxWindSpd = 0;
+        // data shifting
+        for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
+          if (WIND_RECORD_COUNT - m_SampleCount <= idx)
+            m_MinWindDir = wxMin(m_ArrayWindDirHistory[idx], m_MinWindDir);
+          m_MaxWindDir = wxMax(m_ArrayWindDirHistory[idx - 1], m_MaxWindDir);
+          m_MaxWindSpd = wxMax(m_ArrayWindSpdHistory[idx - 1], m_MaxWindSpd);
+          m_ArrayWindDirHistory[idx - 1] = m_ArrayWindDirHistory[idx];
+          m_ArrayWindSpdHistory[idx - 1] = m_ArrayWindSpdHistory[idx];
+          m_ExpSmoothArrayWindSpd[idx - 1] = m_ExpSmoothArrayWindSpd[idx];
+          m_ExpSmoothArrayWindDir[idx - 1] = m_ExpSmoothArrayWindDir[idx];
+          m_ArrayRecTime[idx - 1] = m_ArrayRecTime[idx];
+        }
+        double diff = m_WindDir - m_oldDirVal;
+        if (diff < -270) {
+          m_WindDir += 360;
+        }
+        else if (diff > 270) {
+          m_WindDir -= 360;
+        }
+        m_ArrayWindDirHistory[WIND_RECORD_COUNT - 1] = m_WindDir;
+        m_ArrayWindSpdHistory[WIND_RECORD_COUNT - 1] = m_WindSpd;
+        if (m_SampleCount < 2) {
+          m_ArrayWindSpdHistory[WIND_RECORD_COUNT - 2] = m_WindSpd;
+          m_ExpSmoothArrayWindSpd[WIND_RECORD_COUNT - 2] = m_WindSpd;
+          m_ArrayWindDirHistory[WIND_RECORD_COUNT - 2] = m_WindDir;
+          m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 2] = m_WindDir;
+        }
+        m_ExpSmoothArrayWindSpd[WIND_RECORD_COUNT - 1] =
           alpha * m_ArrayWindSpdHistory[WIND_RECORD_COUNT - 2] +
           (1 - alpha) * m_ExpSmoothArrayWindSpd[WIND_RECORD_COUNT - 2];
-      m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 1] =
+        m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 1] =
           alpha * m_ArrayWindDirHistory[WIND_RECORD_COUNT - 2] +
           (1 - alpha) * m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 2];
-      m_ArrayRecTime[WIND_RECORD_COUNT - 1] = wxDateTime::Now().GetTm();
-      m_oldDirVal = m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 1];
-      // include the new/latest value in the max/min value test too
-      m_MaxWindDir = wxMax(m_WindDir, m_MaxWindDir);
-      m_MinWindDir = wxMin(m_WindDir, m_MinWindDir);
-      m_MaxWindSpd = wxMax(m_WindSpd, m_MaxWindSpd);
-      // get the overall max Wind Speed
-      m_TotalMaxWindSpd = wxMax(m_WindSpd, m_TotalMaxWindSpd);
+        m_ArrayRecTime[WIND_RECORD_COUNT - 1] = wxDateTime::Now().GetTm();
+        m_oldDirVal = m_ExpSmoothArrayWindDir[WIND_RECORD_COUNT - 1];
+        // include the new/latest value in the max/min value test too
+        m_MaxWindDir = wxMax(m_WindDir, m_MaxWindDir);
+        m_MinWindDir = wxMin(m_WindDir, m_MinWindDir);
+        m_MaxWindSpd = wxMax(m_WindSpd, m_MaxWindSpd);
+        // get the overall max Wind Speed
+        m_TotalMaxWindSpd = wxMax(m_WindSpd, m_TotalMaxWindSpd);
 
-      // set wind angle scale to full +/- 90° depending on the real max/min
-      // value recorded
-      SetMinMaxWindScale();
+        // set wind angle scale to full +/- 90 degr depending on the real max/min
+        // value recorded
+        SetMinMaxWindScale();
+        // Wait two times until new data.
+        m_SetNewData = 2;
+      }
     }
+    else m_SetNewData--;
+  }
+}
+
+void DashboardInstrument_WindDirHistory::ResetData() {
+  m_MaxWindDir = -1;
+  m_WindDir = -1;
+  m_WindDirRange = 90;
+  m_MaxWindSpd = 0;
+  m_TotalMaxWindSpd = 0;
+  m_WindSpd = 0;
+  m_SpdRecCnt = 0;
+  m_DirRecCnt = 0;
+  m_SpdStartVal = -1;
+  m_DirStartVal = -1;
+  m_IsRunning = false;
+  m_SetNewData = 0;
+  m_SampleCount = 0;
+  m_LeftLegend = 3;
+  m_RightLegend = 3;
+  for (int idx = 0; idx < WIND_RECORD_COUNT; idx++) {
+    m_ArrayWindDirHistory[idx] = -1;
+    m_ArrayWindSpdHistory[idx] = -1;
+    m_ExpSmoothArrayWindSpd[idx] = -1;
+    m_ExpSmoothArrayWindDir[idx] = -1;
+    m_ArrayRecTime[idx] = wxDateTime::Now().GetTm();
+    m_ArrayRecTime[idx].year = 999;
   }
 }
 
@@ -212,9 +234,9 @@ void DashboardInstrument_WindDirHistory::Draw(wxGCDC* dc) {
 // determine and set  min and max values for the direction
 //*********************************************************************************
 void DashboardInstrument_WindDirHistory::SetMinMaxWindScale() {
-  // set wind direction legend to full +/- 90° depending on the real max/min
-  // value recorded example : max wind dir. = 45°  ==> max = 90°
-  //           min wind dir. = 45°  ==> min = 0°
+  // set wind direction legend to full +/- 90 degr depending on the real max/min
+  // value recorded example : max wind dir. = 45 degr  ==> max = 90 degr
+  //           min wind dir. = 45 degr  ==> min = 0 degr
   // first calculate the max wind direction
   int fulldeg = m_MaxWindDir / 90;  // we explicitly chop off the decimals by
                                     // type conversion from double to int !
@@ -231,7 +253,7 @@ void DashboardInstrument_WindDirHistory::SetMinMaxWindScale() {
     fulldeg = m_MinWindDir > 0 ? fulldeg : (fulldeg - 1);
   m_MinWindDir = fulldeg * 90;
 
-  // limit the visible wind dir range to 360°; remove the extra range on the
+  // limit the visible wind dir range to 360  degr remove the extra range on the
   // opposite side of the current wind dir value
   m_WindDirRange = m_MaxWindDir - m_MinWindDir;
   if (m_WindDirRange > 360) {
@@ -527,8 +549,7 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
       WindAngle = wxString::Format(_T("TWD ---")) + DEGREE_SIGN;
   }
   dc->GetTextExtent(WindAngle, &degw, &degh, 0, 0, g_pFontData);
-  dc->DrawText(WindAngle, m_WindowRect.width - degw - m_RightLegend - 3,
-               m_TopLineHeight - degh);
+  dc->DrawText(WindAngle, m_WindowRect.width - degw - m_RightLegend - 3, 1);
   pen.SetStyle(wxPENSTYLE_SOLID);
   pen.SetColour(wxColour(204, 41, 41, 96));  // red, transparent
   pen.SetWidth(1);
@@ -541,23 +562,26 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
   //---------------------------------------------------------------------------------
   // live direction data
   //---------------------------------------------------------------------------------
-  wxPoint points[WIND_RECORD_COUNT + 2], pointAngle_old;
-  pointAngle_old.x = 3 + m_LeftLegend;
-  pointAngle_old.y = m_TopLineHeight + m_DrawAreaRect.height -
-                     (m_ArrayWindDirHistory[0] - m_MinWindDir) * ratioH;
+  wxPoint points[WIND_RECORD_COUNT + 2];
+  wxPoint wdDraw[WIND_RECORD_COUNT + 2];
+  int ld = 0;
+  wdDraw[ld].x = m_ratioW + 3 + m_LeftLegend;
+  wdDraw[ld].y = m_TopLineHeight + m_DrawAreaRect.height -
+    (m_ArrayWindDirHistory[1] - m_MinWindDir) * ratioH;
+
   for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
     points[idx].x = idx * m_ratioW + 3 + m_LeftLegend;
     points[idx].y = m_TopLineHeight + m_DrawAreaRect.height -
                     (m_ArrayWindDirHistory[idx] - m_MinWindDir) * ratioH;
     if (WIND_RECORD_COUNT - m_SampleCount <= idx &&
-        points[idx].y > m_TopLineHeight && pointAngle_old.y > m_TopLineHeight &&
-        points[idx].y <= m_TopLineHeight + m_DrawAreaRect.height &&
-        pointAngle_old.y <= m_TopLineHeight + m_DrawAreaRect.height)
-      dc->DrawLine(pointAngle_old.x, pointAngle_old.y, points[idx].x,
-                   points[idx].y);
-    pointAngle_old.x = points[idx].x;
-    pointAngle_old.y = points[idx].y;
+                 points[idx].y > m_TopLineHeight &&
+                 points[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
+      wdDraw[ld] = points[idx];
+      ld++;
+    }
   }
+  if (ld > 1)
+    dc->DrawLines(ld, wdDraw);
 
   //---------------------------------------------------------------------------------
   // exponential smoothing of direction
@@ -566,22 +590,25 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
   pen.SetColour(wxColour(204, 41, 41, 255));
   pen.SetWidth(2);
   dc->SetPen(pen);
-  pointAngle_old.x = 3 + m_LeftLegend;
-  pointAngle_old.y = m_TopLineHeight + m_DrawAreaRect.height -
-                     (m_ExpSmoothArrayWindDir[0] - m_MinWindDir) * ratioH;
+
+  ld = 0;
+  wdDraw[ld].x = m_ratioW + 3 + m_LeftLegend;
+  wdDraw[ld].y = m_TopLineHeight + m_DrawAreaRect.height -
+    (m_ExpSmoothArrayWindDir[ld] - m_MinWindDir) * ratioH;
+
   for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
     points[idx].x = idx * m_ratioW + 3 + m_LeftLegend;
     points[idx].y = m_TopLineHeight + m_DrawAreaRect.height -
                     (m_ExpSmoothArrayWindDir[idx] - m_MinWindDir) * ratioH;
     if (WIND_RECORD_COUNT - m_SampleCount <= idx &&
-        points[idx].y > m_TopLineHeight && pointAngle_old.y > m_TopLineHeight &&
-        points[idx].y <= m_TopLineHeight + m_DrawAreaRect.height &&
-        pointAngle_old.y <= m_TopLineHeight + m_DrawAreaRect.height)
-      dc->DrawLine(pointAngle_old.x, pointAngle_old.y, points[idx].x,
-                   points[idx].y);
-    pointAngle_old.x = points[idx].x;
-    pointAngle_old.y = points[idx].y;
+      points[idx].y > m_TopLineHeight &&
+      points[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
+      wdDraw[ld] = points[idx];
+      ld++;
+    }
   }
+  if (ld > 1)
+    dc->DrawLines(ld, wdDraw);
 
   //---------------------------------------------------------------------------------
   // wind speed
@@ -596,8 +623,10 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
     WindSpeed = wxString::Format(_T("TWS --- %s "), m_WindSpeedUnit.c_str());
 
   dc->GetTextExtent(WindSpeed, &degw, &degh, 0, 0, g_pFontData);
-  dc->DrawText(WindSpeed, m_LeftLegend + 3, m_TopLineHeight - degh);
+  dc->DrawText(WindSpeed, m_LeftLegend + 3, 1);
   dc->SetFont(*g_pFontLabel);
+  int labelw, labelh;
+  dc->GetTextExtent(WindSpeed, &labelw, &labelh, 0, 0, g_pFontLabel);
   // determine the time range of the available data (=oldest data value)
   int i = 0;
   while (m_ArrayRecTime[i].year == 999 && i < WIND_RECORD_COUNT - 1) i++;
@@ -613,34 +642,37 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
       wxString::Format(_("Max %.1f %s since %02d:%02d  Overall %.1f %s"),
                        m_MaxWindSpd, m_WindSpeedUnit.c_str(), hour, min,
                        m_TotalMaxWindSpd, m_WindSpeedUnit.c_str()),
-      m_LeftLegend + 3 + 2 + degw, m_TopLineHeight - degh + 5);
+                       m_LeftLegend + 3 + 2 + degw, m_TopLineHeight -1 -labelh);
   pen.SetStyle(wxPENSTYLE_SOLID);
   pen.SetColour(wxColour(61, 61, 204, 96));  // blue, transparent
   pen.SetWidth(1);
   dc->SetPen(pen);
   ratioH = (double)m_DrawAreaRect.height / m_MaxWindSpdScale;
-  wxPoint pointsSpd[WIND_RECORD_COUNT + 2], pointSpeed_old;
-  pointSpeed_old.x = m_LeftLegend + 3;
-  pointSpeed_old.y = m_TopLineHeight + m_DrawAreaRect.height -
-                     m_ArrayWindSpdHistory[0] * ratioH;
+  wxPoint pointsSpd[WIND_RECORD_COUNT + 2];
+  wxPoint spdDraw[WIND_RECORD_COUNT + 2];
 
   //---------------------------------------------------------------------------------
   // live speed data
   //---------------------------------------------------------------------------------
+
+  int ls = 0;
+  spdDraw[ls].x = 1 * m_ratioW + 3 + m_LeftLegend;
+  spdDraw[ls].y = m_TopLineHeight + m_DrawAreaRect.height -
+                      m_ArrayWindSpdHistory[1] * ratioH;
+
   for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
     pointsSpd[idx].x = idx * m_ratioW + 3 + m_LeftLegend;
     pointsSpd[idx].y = m_TopLineHeight + m_DrawAreaRect.height -
                        m_ArrayWindSpdHistory[idx] * ratioH;
     if (WIND_RECORD_COUNT - m_SampleCount <= idx &&
-        pointsSpd[idx].y > m_TopLineHeight &&
-        pointSpeed_old.y > m_TopLineHeight &&
-        pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height &&
-        pointSpeed_old.y <= m_TopLineHeight + m_DrawAreaRect.height)
-      dc->DrawLine(pointSpeed_old.x, pointSpeed_old.y, pointsSpd[idx].x,
-                   pointsSpd[idx].y);
-    pointSpeed_old.x = pointsSpd[idx].x;
-    pointSpeed_old.y = pointsSpd[idx].y;
+      pointsSpd[idx].y > m_TopLineHeight &&
+      pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
+      spdDraw[ls] = pointsSpd[idx];
+      ls++;
+    }
   }
+  if (ls > 1)
+    dc->DrawLines(ls, spdDraw);
 
   //---------------------------------------------------------------------------------
   // exponential smoothing of speed
@@ -649,28 +681,29 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
   pen.SetColour(wxColour(61, 61, 204, 255));  // blue, opaque
   pen.SetWidth(2);
   dc->SetPen(pen);
-  pointSpeed_old.x = m_LeftLegend + 3;
-  pointSpeed_old.y = m_TopLineHeight + m_DrawAreaRect.height -
-                     m_ExpSmoothArrayWindSpd[0] * ratioH;
+  ls = 0;
+  spdDraw[ls].x = 1 * m_ratioW + 3 + m_LeftLegend;
+  spdDraw[ls].y = m_TopLineHeight + m_DrawAreaRect.height -
+                 m_ExpSmoothArrayWindSpd[1] * ratioH;
+
   for (int idx = 1; idx < WIND_RECORD_COUNT; idx++) {
     pointsSpd[idx].x = idx * m_ratioW + 3 + m_LeftLegend;
     pointsSpd[idx].y = m_TopLineHeight + m_DrawAreaRect.height -
                        m_ExpSmoothArrayWindSpd[idx] * ratioH;
     if (WIND_RECORD_COUNT - m_SampleCount <= idx &&
-        pointsSpd[idx].y > m_TopLineHeight &&
-        pointSpeed_old.y > m_TopLineHeight &&
-        pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height &&
-        pointSpeed_old.y <= m_TopLineHeight + m_DrawAreaRect.height)
-      dc->DrawLine(pointSpeed_old.x, pointSpeed_old.y, pointsSpd[idx].x,
-                   pointsSpd[idx].y);
-    pointSpeed_old.x = pointsSpd[idx].x;
-    pointSpeed_old.y = pointsSpd[idx].y;
+      pointsSpd[idx].y > m_TopLineHeight &&
+      pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
+      spdDraw[ls] = pointsSpd[idx];
+      ls++;
+    }
   }
+  if (ls > 1)
+    dc->DrawLines(ls, spdDraw);
 
   //---------------------------------------------------------------------------------
-  // draw vertical timelines every 5 minutes
+  // draw vertical timelines every 10 minutes
   //---------------------------------------------------------------------------------
-  GetGlobalColor(_T("UBLCK"), &col);
+  GetGlobalColor(_T("DASHL"), &col);
   pen.SetColour(col);
   pen.SetStyle(wxPENSTYLE_DOT);
   dc->SetPen(pen);
@@ -680,12 +713,10 @@ void DashboardInstrument_WindDirHistory::DrawForeground(wxGCDC* dc) {
   wxPoint pointTime;
   for (int idx = 0; idx < WIND_RECORD_COUNT; idx++) {
     if (m_ArrayRecTime[idx].year != 999) {
-      wxDateTime localTime(m_ArrayRecTime[i]);
+      wxDateTime localTime(m_ArrayRecTime[idx]);
       hour = localTime.GetHour();
-      sec = localTime.GetSecond();
       min = localTime.GetMinute();
-      if ((hour * 100 + min) != done && (min % 5 == 0) &&
-          (sec == 0 || sec == 1)) {
+      if ((hour * 100 + min) != done && (min % 10 == 0)) {
         pointTime.x = idx * m_ratioW + 3 + m_LeftLegend;
         dc->DrawLine(pointTime.x, m_TopLineHeight + 1, pointTime.x,
                      (m_TopLineHeight + m_DrawAreaRect.height + 1));
