@@ -24,6 +24,8 @@
  ***************************************************************************
  *
  */
+
+#include "pi_gl.h"
 #include "grib_pi.h"
 
 #include "folder.xpm"
@@ -396,7 +398,7 @@ void CursorData::UpdateTrackingControls(void) {
                 wxString::Format(_T("%2d bf"), (int)round(vk))));
     }
 
-    m_tcWindDirection->SetValue(wxString::Format(_T("%03d\u00B0"), (int)(ang)));
+    m_tcWindDirection->SetValue(wxString::Format(_T("%03d%c"), (int)(ang), 0x00B0));
   } else {
     m_tcWindSpeed->SetValue(_("N/A"));
     m_tcWindSpeedBf->SetValue(_("N/A"));
@@ -477,7 +479,7 @@ void CursorData::UpdateTrackingControls(void) {
         m_cursor_lon, m_cursor_lat, true, true);
     if (direction != GRIB_NOTDEF)
       m_tcWaveDirection->SetValue(
-          wxString::Format(_T("%03d\u00B0"), (int)direction));
+          wxString::Format(_T("%03d%c"), (int)direction, 0x00B0));
     else
       m_tcWaveDirection->SetValue(_("N/A"));
   }
@@ -502,7 +504,7 @@ void CursorData::UpdateTrackingControls(void) {
         vkn));
 
     m_tcCurrentDirection->SetValue(
-        wxString::Format(_T("%03d\u00B0"), (int)(ang)));
+        wxString::Format(_T("%03d%c"), (int)(ang), 0x00B0));
   } else {
     m_tcCurrentVelocity->SetValue(_("N/A"));
     m_tcCurrentDirection->SetValue(_("N/A"));
