@@ -31,14 +31,16 @@
 #include "wx/wx.h"
 #endif  // precompiled headers
 
+#include "pi_gl.h"
+
 #include <wx/glcanvas.h>
 #include <wx/graphics.h>
 #include <wx/progdlg.h>
 #include "pi_ocpndc.h"
-
-#ifdef __OCPN__ANDROID__
-#include "qdebug.h"
 #include "pi_shaders.h"
+
+#ifdef __ANDROID__
+#include "qdebug.h"
 #endif
 
 #include "GribUIDialog.h"
@@ -46,6 +48,7 @@
 
 extern int m_Altitude;
 extern bool g_bpause;
+extern double g_ContentScaleFactor;
 
 enum GRIB_OVERLAP { _GIN, _GON, _GOUT };
 
@@ -219,17 +222,6 @@ int adjustSpacing(int dialogSetSpacing) {
 //----------------------------------------------------------------------------------------------------------
 GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
     : m_dlg(dlg), m_Settings(dlg.m_OverlaySettings) {
-#ifdef __WXQT__
-  wxFont fo = GetOCPNGUIScaledFont_PlugIn(_T("Dialog"));
-  m_dFont_war = new wxFont(fo);
-  m_dFont_map = new wxFont(fo);
-#else
-  m_dFont_map = new wxFont(10, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL,
-                           wxFONTWEIGHT_NORMAL);
-  m_dFont_war = new wxFont(16, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_ITALIC,
-                           wxFONTWEIGHT_NORMAL);
-
-#endif
 
   if (wxGetDisplaySize().x > 0) {
     //#ifdef __WXGTK__
@@ -244,10 +236,13 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
   } else
     m_pixelMM = 0.27;  // semi-standard number...
 
+  //qDebug() <<  "m_pixelMM: " << m_pixelMM;
+
   m_pGribTimelineRecordSet = NULL;
   m_last_vp_scale = 0.;
 
   m_oDC = NULL;
+  m_Font_Message = NULL;
 
   InitColorsTable();
   for (int i = 0; i < GribOverlaySettings::SETTINGS_COUNT; i++)
@@ -261,8 +256,11 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
 
   // Generate the wind arrow cache
 
-  if (m_pixelMM < 0.2)
+  if (m_pixelMM < 0.2){
     windArrowSize = 5.0 / m_pixelMM;  // Target scaled arrow size
+    windArrowSize = wxMin(windArrowSize,
+                          wxMax(wxGetDisplaySize().x, wxGetDisplaySize().y) / 20);
+  }
   else
     windArrowSize = 26;  // Standard value for desktop
 
@@ -280,16 +278,16 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
     LineBuffer &arrow = m_WindArrowCache[i];
 
     arrow.pushLine(dec, 0, dec + windArrowSize, 0);                  // hampe
-    arrow.pushLine(dec, 0, dec + pointerLength, pointerLength / 2);  // flèche
+    arrow.pushLine(dec, 0, dec + pointerLength, pointerLength / 2);  // fleche
     arrow.pushLine(dec, 0, dec + pointerLength,
-                   -(pointerLength / 2));  // flèche
+                   -(pointerLength / 2));  // fleche
   }
 
   int featherPosition = windArrowSize / 6;
 
   int b1 =
-      dec + windArrowSize - featherPosition;  // position de la 1ère barbule
-  int b2 = dec + windArrowSize;  // position de la 1ère barbule si >= 10 noeuds
+      dec + windArrowSize - featherPosition;  // position de la 1ere barbule
+  int b2 = dec + windArrowSize;  // position de la 1ere barbule si >= 10 noeuds
 
   int lpetite = windArrowSize / 5;
   int lgrande = lpetite * 2;
@@ -351,6 +349,8 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
     if (i == 0) {
       if (m_pixelMM > 0.2) {
         arrowSize = 5.0 / m_pixelMM;  // Target scaled arrow size
+        arrowSize = wxMin(arrowSize,
+                          wxMax(wxGetDisplaySize().x, wxGetDisplaySize().y) / 20);
         dec1 = arrowSize / 6;         // pointer length
         dec2 = arrowSize / 8;         // space between double lines
       } else
@@ -361,15 +361,15 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
     dec = -arrowSize / 2;
 
     m_SingleArrow[i].pushLine(dec, 0, dec + arrowSize, 0);
-    m_SingleArrow[i].pushLine(dec - 2, 0, dec + dec1, dec1 + 1);     // flèche
-    m_SingleArrow[i].pushLine(dec - 2, 0, dec + dec1, -(dec1 + 1));  // flèche
+    m_SingleArrow[i].pushLine(dec - 2, 0, dec + dec1, dec1 + 1);     // fleche
+    m_SingleArrow[i].pushLine(dec - 2, 0, dec + dec1, -(dec1 + 1));  // fleche
     m_SingleArrow[i].Finalize();
 
     m_DoubleArrow[i].pushLine(dec, -dec2, dec + arrowSize, -dec2);
     m_DoubleArrow[i].pushLine(dec, dec2, dec + arrowSize, +dec2);
 
-    m_DoubleArrow[i].pushLine(dec - 2, 0, dec + dec1, dec1 + 1);     // flèche
-    m_DoubleArrow[i].pushLine(dec - 2, 0, dec + dec1, -(dec1 + 1));  // flèche
+    m_DoubleArrow[i].pushLine(dec - 2, 0, dec + dec1, dec1 + 1);     // fleche
+    m_DoubleArrow[i].pushLine(dec - 2, 0, dec + dec1, -(dec1 + 1));  // fleche
     m_DoubleArrow[i].Finalize();
   }
 }
@@ -380,6 +380,7 @@ GRIBOverlayFactory::~GRIBOverlayFactory() {
   ClearParticles();
 
   if (m_oDC) delete m_oDC;
+  if (m_Font_Message) delete m_Font_Message;
 }
 
 void GRIBOverlayFactory::Reset() {
@@ -388,6 +389,19 @@ void GRIBOverlayFactory::Reset() {
   ClearCachedData();
 }
 
+void GRIBOverlayFactory::SetMessageFont() {
+  wxFont fo;
+#ifdef __WXQT__
+  fo = GetOCPNGUIScaledFont_PlugIn(_T("Dialog"));
+#else
+  fo = *OCPNGetFont(_("Dialog"), 10);
+  fo.SetPointSize((fo.GetPointSize()  * g_ContentScaleFactor / OCPN_GetWinDIPScaleFactor()));
+#endif
+  if (m_Font_Message)
+    delete m_Font_Message;
+  m_Font_Message = new wxFont(fo);
+}
+
 void GRIBOverlayFactory::SetGribTimelineRecordSet(
     GribTimelineRecordSet *pGribTimelineRecordSet) {
   Reset();
@@ -412,7 +426,12 @@ bool GRIBOverlayFactory::RenderGLGribOverlay(wxGLContext *pcontext,
 
   // qDebug() << "RenderGLGribOverlay" << sw.GetTime();
 
-  if (!m_oDC) m_oDC = new pi_ocpnDC();
+  if (!m_oDC || !m_oDC->UsesGL()) {
+    if (m_oDC) {
+      delete m_oDC;
+    }
+    m_oDC = new pi_ocpnDC();
+  }
 
   m_oDC->SetVP(vp);
   m_oDC->SetDC(NULL);
@@ -427,12 +446,17 @@ bool GRIBOverlayFactory::RenderGLGribOverlay(wxGLContext *pcontext,
 }
 
 bool GRIBOverlayFactory::RenderGribOverlay(wxDC &dc, PlugIn_ViewPort *vp) {
-  if (!m_oDC) m_oDC = new pi_ocpnDC();
+  if (!m_oDC || m_oDC->UsesGL()) {
+    if (m_oDC) {
+      delete m_oDC;
+    }
+    m_oDC = new pi_ocpnDC(dc);
+  }
 
   m_oDC->SetVP(vp);
   m_oDC->SetDC(&dc);
 
-  m_pdc = NULL;
+  m_pdc = &dc;
 #if 0
 #if wxUSE_GRAPHICS_CONTEXT
     wxMemoryDC *pmdc;
@@ -510,22 +534,16 @@ void GRIBOverlayFactory::SettingsIdToGribId(int i, int &idx, int &idy,
 
 bool GRIBOverlayFactory::DoRenderGribOverlay(PlugIn_ViewPort *vp) {
   if (!m_pGribTimelineRecordSet) {
-    DrawMessageWindow((m_Message), vp->pix_width, vp->pix_height, m_dFont_war);
+    DrawMessageWindow((m_Message), vp->pix_width, vp->pix_height, m_Font_Message);
     return false;
   }
 
   // setup numbers texture if needed
   if (!m_pdc) {
-#ifdef __WXQT__
-    wxFont font = GetOCPNGUIScaledFont_PlugIn(_T("Dialog"));
-#else
-    wxFont font(9, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL,
-                wxFONTWEIGHT_NORMAL);
-#endif
-    m_TexFontNumbers.Build(font);
+    m_TexFontNumbers.Build(*m_Font_Message);
 
     if (m_oDC)
-      m_oDC->SetFont(font);
+      m_oDC->SetFont(*m_Font_Message);
   }
 
   m_Message_Hiden.Empty();
@@ -543,7 +561,8 @@ bool GRIBOverlayFactory::DoRenderGribOverlay(PlugIn_ViewPort *vp) {
     for (int i = 0; i < GribOverlaySettings::SETTINGS_COUNT; i++) {
       if (i == GribOverlaySettings::WIND) {
         if (overlay) { /* render overlays first */
-          if (m_dlg.m_bDataPlot[i]) RenderGribOverlayMap(i, pGR, vp);
+          if (m_dlg.m_bDataPlot[i])
+            RenderGribOverlayMap(i, pGR, vp);
         } else {
           if (m_dlg.m_bDataPlot[i]) {
             RenderGribBarbedArrows(i, pGR, vp);
@@ -596,7 +615,7 @@ bool GRIBOverlayFactory::DoRenderGribOverlay(PlugIn_ViewPort *vp) {
   if (!m_Message_Hiden.IsEmpty()) m_Message_Hiden.Append(_T("\n"));
   m_Message_Hiden.Append(m_Message);
   DrawMessageWindow(m_Message_Hiden, vp->pix_width, vp->pix_height,
-                    m_dFont_map);
+    m_Font_Message);
   return true;
 }
 
@@ -626,19 +645,10 @@ void GRIBOverlayFactory::GetCalibratedGraphicColor(int settings, double val_in,
   } else
     r = 255, g = 255, b = 255, a = 0;
 
-    /* for some reason r g b values are inverted, but not alpha,
-       this fixes it, but I would like to find the actual cause */
-#ifndef __OCPN__ANDROID__
-  data[0] = 255 - r;
-  data[1] = 255 - g;
-  data[2] = 255 - b;
-  data[3] = a;
-#else
   data[0] = r;
   data[1] = g;
   data[2] = b;
   data[3] = a;
-#endif
 }
 
 bool GRIBOverlayFactory::CreateGribGLTexture(GribOverlay *pGO, int settings,
@@ -828,7 +838,7 @@ bool GRIBOverlayFactory::CreateGribGLTexture(GribOverlay *pGO, int settings,
   glTexParameteri(texture_format, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
   glTexParameteri(texture_format, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 
-#ifndef USE_ANDROID_GLES2
+#if 0//ndef USE_ANDROID_GLES2
   glPushClientAttrib(GL_CLIENT_PIXEL_STORE_BIT);
 
   glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
@@ -1883,7 +1893,7 @@ void GRIBOverlayFactory::DrawNumbers(wxPoint p, double value, int settings,
     m_pdc->DrawBitmap(label, p.x, p.y, true);
   } else {
 #ifdef ocpnUSE_GL
-#ifndef USE_ANDROID_GLES2
+#if 0 //ndef USE_ANDROID_GLES2
 
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -2333,6 +2343,8 @@ void GRIBOverlayFactory::DrawMessageWindow(wxString msg, int x, int y,
                                            wxFont *mfont) {
   if (msg.empty()) return;
 
+  int ScaleBare_H = 30;//futur : get the position/size from API?
+
   if (m_pdc) {
     wxDC &dc = *m_pdc;
     dc.SetFont(*mfont);
@@ -2342,7 +2354,7 @@ void GRIBOverlayFactory::DrawMessageWindow(wxString msg, int x, int y,
     int w, h;
     dc.GetMultiLineTextExtent(msg, &w, &h);
     h += 2;
-    int yp = y - (2 * GetChartbarHeight() + h);
+    int yp = y - (ScaleBare_H + GetChartbarHeight() + h);
 
     int label_offset = 10;
     int wdraw = w + (label_offset * 2);
@@ -2358,10 +2370,13 @@ void GRIBOverlayFactory::DrawMessageWindow(wxString msg, int x, int y,
       int w, h;
       m_oDC->GetTextExtent(msg, &w, &h);
       h += 2;
-      int yp = y - (2 * GetChartbarHeight() + h);
 
       int label_offset = 10;
       int wdraw = w + (label_offset * 2);
+      wdraw *= g_ContentScaleFactor;
+      h *= g_ContentScaleFactor;
+      int yp = y - (ScaleBare_H + GetChartbarHeight() + h);
+
       m_oDC->DrawRectangle(0, yp, wdraw, h);
       m_oDC->DrawText(msg, label_offset, yp);
     }
@@ -2447,7 +2462,7 @@ void GRIBOverlayFactory::drawWindArrowWithBarbs(int settings, int x, int y,
 #else
   float penWidth = .4 / m_pixelMM;
 #endif
-  penWidth = wxMax(penWidth, 2.0);
+  penWidth = wxMin(penWidth, 3.0);
 
   if (m_pdc) {
     wxPen pen(arrowColor, 2);
@@ -2549,7 +2564,7 @@ void GRIBOverlayFactory::drawLineBuffer(LineBuffer &buffer, int x, int y,
 void GRIBOverlayFactory::DrawSingleGLTexture(GribOverlay *pGO, GribRecord *pGR,
                                              double uv[], double x, double y,
                                              double width, double height) {
-#ifdef __OCPN__ANDROID__
+#if 1//def __OCPN__ANDROID__
 
   glEnable(texture_format);
 
@@ -2704,7 +2719,7 @@ void GRIBOverlayFactory::DrawGLTexture(GribOverlay *pGO, GribRecord *pGR,
 
   // optimization for non-rotated mercator, since longitude is linear
   if (vp->rotation == 0 && vp->m_projection_type == PI_PROJECTION_MERCATOR)
-    xsquares = 1;
+     xsquares = 1;
 
   // It is possible to have only 1 square when the viewport covers more than
   // 180 longitudes but there is more logic needed.  This is simpler.
@@ -2730,6 +2745,7 @@ void GRIBOverlayFactory::DrawGLTexture(GribOverlay *pGO, GribRecord *pGR,
 
   for (double y = 0; y < vp->pix_height + ys / 2; y += ys) {
     i = 0;
+
     for (double x = 0; x < vp->pix_width + xs / 2; x += xs) {
       double lat, lon;
       wxPoint p(x, y);
@@ -2784,7 +2800,9 @@ void GRIBOverlayFactory::DrawGLTexture(GribOverlay *pGO, GribRecord *pGR,
           uv[6] = u3;
           uv[7] = v3;
 
-          DrawSingleGLTexture(pGO, pGR, uv, x, y, xs, ys);
+          if(u1 > u0){
+            DrawSingleGLTexture(pGO, pGR, uv, x, y, xs, ys);
+          }
         }
       }
 
