@@ -28,20 +28,10 @@
 
 #include <wx/geometry.h>
 
-#ifdef __OCPN__ANDROID__
-#include <qopengl.h>
-#include "GL/gl_private.h"
-#else
-#include "GL/gl.h"
-#endif
-
-#ifdef USE_ANDROID_GLES2
-#include <GLES2/gl2.h>
-#endif
+#include "pi_gl.h"
 
 #include "pi_ocpndc.h"
-
-#include "TexFont.h"
+#include "pi_TexFont.h"
 
 //----------------------------------------------------------------------------------------------------------
 //    Grib Overlay Specification
@@ -166,7 +156,7 @@ public:
     m_bDrawBarbedArrowHead = BarbedArrowHead;
     ClearCachedData();
   }
-
+  void SetMessageFont();
   void SetMessage(wxString message) { m_Message = message; }
   void SetTimeZone(int TimeZone) { m_TimeZone = TimeZone; }
   void SetParentSize(int w, int h) {
@@ -257,8 +247,7 @@ private:
   wxGraphicsContext *m_gdc;
 #endif
 
-  wxFont *m_dFont_map;
-  wxFont *m_dFont_war;
+  wxFont *m_Font_Message;
 
   bool m_hiDefGraphics;
   bool m_bGradualColors;
