@@ -42,6 +42,8 @@
 #include <math.h>
 #include <time.h>
 
+#include "pi_gl.h"
+
 #include "grib_pi.h"
 #include "GribTable.h"
 #include "email.h"
@@ -713,7 +715,7 @@ void GRIBUICtrlBar::SetDialogsStyleSizePosition(bool force_recompute) {
   if ((m_DialogStyle >> 1 == SEPARATED || !m_CDataIsShown) &&
       !m_HasCaption) {  // Size and show grabber if necessary
     Fit();              // each time CtrlData dialog will be alone
-    m_gGrabber->Size(m_ScaledFactor);  // or separated
+    m_gGrabber->Size();  // or separated
     m_gGrabber->Show();
   }
 
@@ -811,9 +813,6 @@ void GRIBUICtrlBar::OnAltitude(wxCommandEvent &event) {
   amenu->Connect(wxEVT_COMMAND_MENU_SELECTED,
                  wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), NULL, this);
 
-#ifdef __WXMSW__
-  const wxString l[] = {_T(" "), wxString::Format(_T("\u2022"))};
-#endif
   for (int i = 0; i < 5; i++) {
     if (((m_pTimelineSet &&
           m_bGRIBActiveFile->m_GribIdxArray.Index(Idx_WIND_VX + i) !=
@@ -823,9 +822,7 @@ void GRIBUICtrlBar::OnAltitude(wxCommandEvent &event) {
         i == 0) {
       MenuAppend(
           amenu, ID_CTRLALTITUDE + 1000 + i,
-#ifdef __WXMSW__
-          (i == m_Altitude ? l[1] : l[0]) +
-#endif
+
               m_OverlaySettings.GetAltitudeFromIndex(
                   i, m_OverlaySettings.Settings[GribOverlaySettings::PRESSURE]
                          .m_Units),
@@ -899,12 +896,17 @@ void GRIBUICtrlBar::OnMenuEvent(wxMenuEvent &event) {
 void GRIBUICtrlBar::MenuAppend(wxMenu *menu, int id, wxString label,
                                wxItemKind kind, wxBitmap bitmap,
                                wxMenu *submenu) {
-  wxMenuItem *item = new wxMenuItem(menu, id, label, _T(""), kind, submenu);
+  wxMenuItem *item = new wxMenuItem(menu, id, label, _T(""), kind);
+  //add a submenu to this item if necessary
+  if (submenu)
+    item->SetSubMenu(submenu);
 
+/* Menu font do not work properly for MSW (wxWidgets 3.2.1)
 #ifdef __WXMSW__
   wxFont *qFont = OCPNGetFont(_("Menu"), 10);
   item->SetFont(*qFont);
 #endif
+*/
 
 #if defined(__WXMSW__) || defined(__WXGTK__)
   if (!bitmap.IsSameAs(wxNullBitmap)) item->SetBitmap(bitmap);
@@ -926,9 +928,6 @@ void GRIBUICtrlBar::OnMouseEvent(wxMouseEvent &event) {
                      wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), NULL,
                      this);
 
-#ifdef __WXMSW__
-      const wxString l[] = {_T(" "), wxString::Format(_T("\u2022"))};
-#endif
       for (int i = 0; i < 5; i++) {
         if (((m_pTimelineSet &&
               m_bGRIBActiveFile->m_GribIdxArray.Index(Idx_WIND_VX + i) !=
@@ -937,9 +936,6 @@ void GRIBUICtrlBar::OnMouseEvent(wxMouseEvent &event) {
                   wxNOT_FOUND)) ||
             i == 0) {
           MenuAppend(smenu, ID_CTRLALTITUDE + 1000 + i,
-#ifdef __WXMSW__
-                     (i == m_Altitude ? l[1] : l[0]) +
-#endif
                          m_OverlaySettings.GetAltitudeFromIndex(
                              i, m_OverlaySettings
                                     .Settings[GribOverlaySettings::PRESSURE]
@@ -950,7 +946,7 @@ void GRIBUICtrlBar::OnMouseEvent(wxMouseEvent &event) {
       smenu->Check(ID_CTRLALTITUDE + 1000 + m_Altitude, true);
       MenuAppend(
           xmenu, wxID_ANY, _("Select geopotential altitude"), wxITEM_NORMAL,
-          GetScaledBitmap(wxBitmap(altitude), _T("altitude"), m_ScaledFactor));
+          GetScaledBitmap(wxBitmap(altitude), _T("altitude"), m_ScaledFactor),smenu);
     }
     MenuAppend(xmenu, ID_BTNNOW, _("Now"), wxITEM_NORMAL,
                GetScaledBitmap(wxBitmap(now), _T("now"), m_ScaledFactor));
