@@ -31,9 +31,14 @@
 #include "wx/wx.h"
 #endif
 
+#include <list>
+
+#include "pi_gl.h"
+
 #ifndef __OCPN__ANDROID__
-#include <GL/gl.h>
-#include <GL/glu.h>
+//#include <GL/glew.h>
+//#include <GL/gl.h>
+//#include <GL/glu.h>
 #endif
 
 #include "ocpn_plugin.h"
@@ -56,15 +61,8 @@
 #include "wx28compat.h"
 #include "cutil.h"
 
-#ifdef __OCPN__ANDROID__
-#include <qopengl.h>
-#include "GL/gl_private.h"
-#else
-#include "GL/gl.h"
-#endif
-
-#ifdef USE_ANDROID_GLES2
 #include "pi_shaders.h"
+#ifdef USE_ANDROID_GLES2
 #include <GLES2/gl2.h>
 #endif
 
@@ -95,14 +93,14 @@ int NextPow2(int size) {
 //----------------------------------------------------------------------------
 /* pass the dc to the constructor, or NULL to use opengl */
 pi_ocpnDC::pi_ocpnDC(wxGLCanvas &canvas)
-    : glcanvas(&canvas), dc(NULL), m_pen(wxNullPen), m_brush(wxNullBrush) {
+    : glcanvas(&canvas), dc(NULL), m_pen(wxNullPen), m_brush(wxNullBrush), m_buseGL(true) {
 #if wxUSE_GRAPHICS_CONTEXT
   pgc = NULL;
 #endif
 #ifdef ocpnUSE_GL
   m_textforegroundcolour = wxColour(0, 0, 0);
 #endif
-  m_buseTex = GetLocaleCanonicalName().IsSameAs(_T("en_US"));
+  m_buseTex = false; //GetLocaleCanonicalName().IsSameAs(_T("en_US"));
   workBuf = NULL;
   workBufSize = 0;
   s_odc_tess_work_buf = NULL;
@@ -115,14 +113,14 @@ pi_ocpnDC::pi_ocpnDC(wxGLCanvas &canvas)
   s_odc_tess_work_buf = (GLfloat *)malloc(100 * sizeof(GLfloat));
   s_odc_tess_buf_len = 100;
 
-#ifdef USE_ANDROID_GLES2
+#if 1 //def USE_ANDROID_GLES2
   pi_loadShaders();
 #endif
 #endif
 }
 
 pi_ocpnDC::pi_ocpnDC(wxDC &pdc)
-    : glcanvas(NULL), dc(&pdc), m_pen(wxNullPen), m_brush(wxNullBrush) {
+    : glcanvas(NULL), dc(&pdc), m_pen(wxNullPen), m_brush(wxNullBrush), m_buseGL(false) {
 #if wxUSE_GRAPHICS_CONTEXT
   pgc = NULL;
   wxMemoryDC *pmdc = wxDynamicCast(dc, wxMemoryDC);
@@ -134,24 +132,24 @@ pi_ocpnDC::pi_ocpnDC(wxDC &pdc)
   }
 #endif
   m_textforegroundcolour = wxColour(0, 0, 0);
-  m_buseTex = GetLocaleCanonicalName().IsSameAs(_T("en_US"));
+  m_buseTex = false; //GetLocaleCanonicalName().IsSameAs(_T("en_US"));
   workBuf = NULL;
   workBufSize = 0;
   s_odc_tess_work_buf = NULL;
 }
 
 pi_ocpnDC::pi_ocpnDC()
-    : glcanvas(NULL), dc(NULL), m_pen(wxNullPen), m_brush(wxNullBrush) {
+    : glcanvas(NULL), dc(NULL), m_pen(wxNullPen), m_brush(wxNullBrush), m_buseGL(true) {
 #if wxUSE_GRAPHICS_CONTEXT
   pgc = NULL;
 #endif
   m_textforegroundcolour = wxColour(0, 0, 0);
-  m_buseTex = GetLocaleCanonicalName().IsSameAs(_T("en_US"));
+  m_buseTex = false; //GetLocaleCanonicalName().IsSameAs(_T("en_US"));
   workBuf = NULL;
   workBufSize = 0;
   s_odc_tess_work_buf = NULL;
 
-#ifdef USE_ANDROID_GLES2
+#if 1 //def USE_ANDROID_GLES2
   pi_loadShaders();
 #endif
 }
@@ -166,9 +164,11 @@ pi_ocpnDC::~pi_ocpnDC() {
 }
 
 void pi_ocpnDC::SetVP(PlugIn_ViewPort *vp) {
-#ifdef __OCPN__ANDROID__
-  configureShaders(vp->pix_width, vp->pix_height);
-#endif
+//#ifdef __OCPN__ANDROID__
+  if ( m_buseGL ) {
+    configureShaders(vp->pix_width, vp->pix_height);
+  }
+//#endif
   m_vpSize = wxSize(vp->pix_width, vp->pix_height);
 }
 
@@ -274,22 +274,22 @@ void pi_ocpnDC::SetGLStipple() const {
 
 #ifndef USE_ANDROID_GLES2
   switch (m_pen.GetStyle()) {
-    case wxDOT: {
+    case wxPENSTYLE_DOT: {
       glLineStipple(1, 0x3333);
       glEnable(GL_LINE_STIPPLE);
       break;
     }
-    case wxLONG_DASH: {
+    case wxPENSTYLE_LONG_DASH: {
       glLineStipple(1, 0xFFF8);
       glEnable(GL_LINE_STIPPLE);
       break;
     }
-    case wxSHORT_DASH: {
+    case wxPENSTYLE_SHORT_DASH: {
       glLineStipple(1, 0x3F3F);
       glEnable(GL_LINE_STIPPLE);
       break;
     }
-    case wxDOT_DASH: {
+    case wxPENSTYLE_DOT_DASH: {
       glLineStipple(1, 0x8FF1);
       glEnable(GL_LINE_STIPPLE);
       break;
@@ -582,7 +582,7 @@ void pi_ocpnDC::DrawLine(wxCoord x1, wxCoord y1, wxCoord x2, wxCoord y2,
         glLineWidth(pen_width);
     }
 
-#ifdef USE_ANDROID_GLES2
+#if 1//def USE_ANDROID_GLES2
     if (b_draw_thick)
       piDrawGLThickLine(x1, y1, x2, y2, m_pen, b_hiqual);
     else {
@@ -883,7 +883,7 @@ void pi_ocpnDC::DrawLines(int n, wxPoint points[], wxCoord xoffset,
       return;
     }
 
-#ifndef USE_ANDROID_GLES2
+#if 0 //ndef USE_ANDROID_GLES2
 
     glBegin(GL_LINE_STRIP);
     for (int i = 0; i < n; i++)
@@ -972,6 +972,9 @@ void pi_ocpnDC::StrokeLines(int n, wxPoint *points) {
 
 void pi_ocpnDC::DrawGLLineArray(int n, float *vertex_array, float *color_array,
                                 unsigned char *color_array_ub, bool b_hiqual) {
+  if(!n)
+      return;
+
 #ifdef ocpnUSE_GL
   if (ConfigurePen()) {
 #ifdef __WXQT__
@@ -1006,7 +1009,7 @@ void pi_ocpnDC::DrawGLLineArray(int n, float *vertex_array, float *color_array,
         glLineWidth(wxMax(g_piGLMinSymbolLineWidth, 1));
     }
 
-#ifndef USE_ANDROID_GLES2
+#if 0//ndef USE_ANDROID_GLES2
 
     glEnableClientState(GL_VERTEX_ARRAY);
     glEnableClientState(GL_COLOR_ARRAY);
@@ -1055,7 +1058,7 @@ void pi_ocpnDC::DrawRectangle(wxCoord x, wxCoord y, wxCoord w, wxCoord h) {
   if (dc) dc->DrawRectangle(x, y, w, h);
 #ifdef ocpnUSE_GL
   else {
-#ifndef USE_ANDROID_GLES2
+#if 0//ndef USE_ANDROID_GLES2
     if (ConfigureBrush()) {
       glBegin(GL_QUADS);
       glVertex2i(x, y);
@@ -1161,7 +1164,7 @@ void pi_ocpnDC::DrawRoundedRectangle(wxCoord x, wxCoord y, wxCoord w, wxCoord h,
     wxCoord x1 = x + r, x2 = x + w - r;
     wxCoord y1 = y + r, y2 = y + h - r;
 
-#ifdef USE_ANDROID_GLES2
+#if 1//def USE_ANDROID_GLES2
 
     //  Grow the work buffer as necessary
     size_t bufReq = steps * 8 * 2 * sizeof(float);  // large, to be sure
@@ -1537,7 +1540,7 @@ typedef union {
   } info;
 } GLvertex;
 
-#ifndef USE_ANDROID_GLES2
+#if 0 //ndef USE_ANDROID_GLES2
 void APIENTRY pi_ocpnDCcombineCallback(GLdouble coords[3],
                                        GLdouble *vertex_data[4],
                                        GLfloat weight[4], GLdouble **dataOut) {
@@ -1577,7 +1580,7 @@ void APIENTRY ocpnDCendCallback() { glEnd(); }
 
 // GLSL callbacks
 
-#ifdef USE_ANDROID_GLES2
+#if 1 //def USE_ANDROID_GLES2
 
 static std::list<double *> odc_combine_work_data;
 static void pi_odc_combineCallbackD(GLdouble coords[3],
@@ -1675,7 +1678,7 @@ void pi_ocpnDC::DrawPolygonTessellated(int n, wxPoint points[], wxCoord xoffset,
       return;
     }
 
-#ifdef USE_ANDROID_GLES2
+#if 1 //def USE_ANDROID_GLES2
     m_tobj = gluNewTess();
     s_odc_tess_vertex_idx = 0;
 
@@ -1874,7 +1877,7 @@ void pi_ocpnDC::DrawText(const wxString &text, wxCoord x, wxCoord y) {
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 
-#ifndef USE_ANDROID_GLES2
+#if 0//ndef USE_ANDROID_GLES2
         glPushMatrix();
         glTranslatef(x, y, 0);
 
@@ -1892,7 +1895,15 @@ void pi_ocpnDC::DrawText(const wxString &text, wxCoord x, wxCoord y) {
     } else {
       wxScreenDC sdc;
       sdc.SetFont(m_font);
-      sdc.GetTextExtent(text, &w, &h, NULL, NULL, &m_font);
+      sdc.GetMultiLineTextExtent(text, &w, &h, NULL, &m_font); /*we need to handle multiline*/
+      int ww, hw;
+      sdc.GetTextExtent("W", &ww, &hw); // metric
+      w += ww;    // RHS padding.
+      w *= OCPN_GetWinDIPScaleFactor();
+      h *= OCPN_GetWinDIPScaleFactor();
+
+      h *= 2;   //TODO //Some trouble with math or text sizing.
+                // Add "fluff" to text bitmap size.
 
       /* create bitmap of appropriate size and select it */
       wxBitmap bmp(w, h);
@@ -1973,7 +1984,7 @@ void pi_ocpnDC::DrawText(const wxString &text, wxCoord x, wxCoord y) {
 
       float u = (float)w / TextureWidth, v = (float)h / TextureHeight;
 
-#ifndef USE_ANDROID_GLES2
+#if 0//ndef USE_ANDROID_GLES2
       glColor3ub(0, 0, 0);
 
       glBegin(GL_QUADS);
@@ -2010,14 +2021,14 @@ void pi_ocpnDC::DrawText(const wxString &text, wxCoord x, wxCoord y) {
       coords[6] = 0;
       coords[7] = h;
 
-      glUseProgram(texture_2D_shader_program);
+      glUseProgram(pi_texture_2D_shader_program);
 
       // Get pointers to the attributes in the program.
-      GLint mPosAttrib = glGetAttribLocation(texture_2D_shader_program, "aPos");
-      GLint mUvAttrib = glGetAttribLocation(texture_2D_shader_program, "aUV");
+      GLint mPosAttrib = glGetAttribLocation(pi_texture_2D_shader_program, "aPos");
+      GLint mUvAttrib = glGetAttribLocation(pi_texture_2D_shader_program, "aUV");
 
       // Set up the texture sampler to texture unit 0
-      GLint texUni = glGetUniformLocation(texture_2D_shader_program, "uTex");
+      GLint texUni = glGetUniformLocation(pi_texture_2D_shader_program, "uTex");
       glUniform1i(texUni, 0);
 
       // Disable VBO's (vertex buffer objects) for attributes.
@@ -2046,7 +2057,7 @@ void pi_ocpnDC::DrawText(const wxString &text, wxCoord x, wxCoord y) {
       Q[3][1] = y;
 
       GLint matloc =
-          glGetUniformLocation(texture_2D_shader_program, "TransformMatrix");
+          glGetUniformLocation(pi_texture_2D_shader_program, "TransformMatrix");
       glUniformMatrix4fv(matloc, 1, GL_FALSE, (const GLfloat *)Q);
 
       // Select the active texture unit.
@@ -2105,8 +2116,9 @@ void pi_ocpnDC::GetTextExtent(const wxString &string, wxCoord *w, wxCoord *h,
   if (w) *w = 100;
   if (h) *h = 100;
 
+  /*we need to handle multiline to get true w & h */
   if (dc)
-    dc->GetTextExtent(string, w, h, descent, externalLeading, font);
+    dc->GetMultiLineTextExtent(string, w, h, NULL, font);
   else {
     wxFont f = m_font;
     if (font) f = *font;
@@ -2117,11 +2129,15 @@ void pi_ocpnDC::GetTextExtent(const wxString &string, wxCoord *w, wxCoord *h,
       m_texfont.GetTextExtent(string, w, h);
 #else
       wxMemoryDC temp_dc;
-      temp_dc.GetTextExtent(string, w, h, descent, externalLeading, &f);
+      temp_dc.GetMultiLineTextExtent(string, w, h, NULL, &f);
+      if (w) (*w) *= OCPN_GetWinDIPScaleFactor();
+      if (h) (*h) *= OCPN_GetWinDIPScaleFactor();
 #endif
     } else {
       wxMemoryDC temp_dc;
-      temp_dc.GetTextExtent(string, w, h, descent, externalLeading, &f);
+      temp_dc.GetMultiLineTextExtent(string, w, h, NULL, &f);
+      if (w) (*w) *= OCPN_GetWinDIPScaleFactor();
+      if (h) (*h) *= OCPN_GetWinDIPScaleFactor();
     }
   }
 
