@@ -26,13 +26,13 @@
  *
  */
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 
-#include "wx/artprov.h"
+#include <wx/artprov.h>
 #include <wx/statline.h>
 
 #include "dychart.h"
@@ -41,10 +41,7 @@
 #include "CanvasOptions.h"
 #include "OCPNPlatform.h"
 #include "gui_lib.h"
-
-#ifdef ocpnUSE_SVG
-#include "wxSVG/svg.h"
-#endif  // ocpnUSE_SVG
+#include "s52s57.h"
 
 #ifdef __OCPN__ANDROID__
 #include "androidUTIL.h"
@@ -309,6 +306,14 @@ CanvasOptions::CanvasOptions(wxWindow* parent)
       wxEVT_COMMAND_CHECKBOX_CLICKED,
       wxCommandEventHandler(CanvasOptions::OnOptionChange), NULL, this);
 
+  pCBENCDataQuality =
+  new wxCheckBox(pDisplayPanel, IDCO_ENCDATAQUALITY_CHECKBOX,
+                 _("Show chart data quality"));
+  boxENC->Add(pCBENCDataQuality, verticalInputFlags);
+  pCBENCDataQuality->Connect(
+    wxEVT_COMMAND_CHECKBOX_CLICKED,
+    wxCommandEventHandler(CanvasOptions::OnOptionChange), NULL, this);
+
   // spacer
   boxENC->Add(0, interGroupSpace);
 
@@ -387,6 +392,7 @@ void CanvasOptions::RefreshControlValues(void) {
   pCBENCLights->SetValue(parentCanvas->GetShowENCLights());
   pCBENCAnchorDetails->SetValue(parentCanvas->GetShowENCAnchor());
   pCBENCVisibleSectors->SetValue(parentCanvas->GetShowVisibleSectors());
+  pCBENCDataQuality->SetValue(parentCanvas->GetShowENCDataQual());
 
   // pCBENCLightDesc->Enable(parentCanvas->GetShowENCLights());
 
@@ -420,8 +426,9 @@ void CanvasOptions::RefreshControlValues(void) {
   pCBENCLights->Enable(m_ENCAvail);
   pCBENCVisibleSectors->Enable(m_ENCAvail);
 
-  //  Anchor conditions are only available if display category is "All" or "User
-  //  Standard"
+  //  Anchor conditions  and dateQuality are only available if display category
+  //  is "All" or "User Standard"
+  pCBENCDataQuality->Enable(m_ENCAvail && (nset > 1));
   pCBENCAnchorDetails->Enable(m_ENCAvail && (nset > 1));
 
   //  Many options are not valid if display category is "Base"
@@ -432,6 +439,7 @@ void CanvasOptions::RefreshControlValues(void) {
     pCBENCBuoyLabels->Disable();
     pCBENCLights->Disable();
     pCBENCVisibleSectors->Disable();
+    pCBENCDataQuality->Disable();
   }
 
   m_pDispCat->Enable(m_ENCAvail);
@@ -528,6 +536,12 @@ void CanvasOptions::UpdateCanvasOptions(void) {
     b_needReLoad = true;
   }
 
+  if (pCBENCDataQuality->GetValue() !=
+    parentCanvas->GetShowENCDataQual()) {
+    parentCanvas->SetShowENCDataQual(pCBENCDataQuality->GetValue());
+  b_needReLoad = true;
+    }
+
   int newMode = NORTH_UP_MODE;
   if (pCBCourseUp->GetValue())
     newMode = COURSE_UP_MODE;
