@@ -29,6 +29,7 @@
 #include <wx/tokenzr.h>
 
 #include "config.h"
+#include "config_vars.h"
 #include "ConfigMgr.h"
 
 #include <wx/filename.h>
@@ -46,7 +47,6 @@
 #include <wx/listimpl.cpp>
 #include <wx/progdlg.h>
 
-#include "chart1.h"
 #include "navutil.h"
 #include "chcanv.h"
 #include "georef.h"
@@ -57,20 +57,21 @@
 #include "chartbase.h"
 #include "ocpndc.h"
 #include "geodesic.h"
-#include "datastream.h"
 #include "multiplexer.h"
+#include "nmea0183.h"
 #include "ais.h"
-#include "Route.h"
-#include "Select.h"
+#include "route.h"
+#include "select.h"
 #include "FontMgr.h"
 #include "Layer.h"
-#include "NavObjectCollection.h"
+#include "nav_object_database.h"
 #include "NMEALogWindow.h"
-#include "AIS_Decoder.h"
+#include "ais_decoder.h"
 #include "OCPNPlatform.h"
-#include "Track.h"
+#include "track.h"
 #include "chartdb.h"
 #include "CanvasConfig.h"
+#include "ocpn_frame.h"
 
 #include "s52plib.h"
 #include "cm93.h"
@@ -92,7 +93,6 @@ extern MyConfig *pConfig;
 extern double initial_scale_ppm, initial_rotation;
 extern int g_nbrightness;
 extern bool g_bShowTrue, g_bShowMag;
-extern double g_UserVar;
 extern bool g_bShowStatusBar;
 extern bool g_bUIexpert;
 extern bool g_bFullscreen;
@@ -124,7 +124,6 @@ extern bool g_bsmoothpanzoom;
 extern bool g_bShowOutlines;
 extern bool g_bShowActiveRouteHighway;
 extern bool g_bShowRouteTotal;
-extern int g_nNMEADebug;
 extern int g_nAWDefault;
 extern int g_nAWMax;
 extern int g_nTrackPrecision;
@@ -161,6 +160,7 @@ extern double g_MarkLost_Mins;
 extern bool g_bRemoveLost;
 extern double g_RemoveLost_Mins;
 extern bool g_bShowCOG;
+extern bool g_bSyncCogPredictors;
 extern double g_ShowCOG_Mins;
 extern bool g_bAISShowTracks;
 extern bool g_bTrackCarryOver;
@@ -195,7 +195,6 @@ extern bool g_bDrawAISRealtime;
 extern double g_AIS_RealtPred_Kts;
 extern bool g_bShowAISName;
 extern int g_Show_Target_Name_Scale;
-extern bool g_bWplUsePosition;
 extern int g_WplAction;
 extern bool g_benableAISNameCache;
 extern int g_ScaledNumWeightSOG;
@@ -222,7 +221,6 @@ extern bool g_bEnableZoomToCursor;
 extern wxString g_toolbarConfig;
 extern double g_TrackIntervalSeconds;
 extern double g_TrackDeltaDistance;
-extern int gps_watchdog_timeout_ticks;
 
 extern bool g_bGDAL_Debug;
 extern bool g_bDebugCM93;
@@ -312,11 +310,9 @@ extern wxString g_default_wp_icon;
 extern ChartGroupArray *g_pGroupArray;
 
 extern bool g_bDebugOGL;
-extern wxString g_GPS_Ident;
-extern bool g_bGarminHostUpload;
 extern wxString g_uploadConnection;
 
-extern wxArrayString TideCurrentDataSet;
+extern std::vector<std::string> TideCurrentDataSet;
 extern wxString g_TCData_Dir;
 
 extern bool g_btouch;
@@ -325,16 +321,13 @@ extern bool g_bresponsive;
 extern bool g_bGLexpert;
 
 extern int g_SENC_LOD_pixels;
-extern ArrayOfMMSIProperties g_MMSI_Props_Array;
+extern ArrayOfMmsiProperties g_MMSI_Props_Array;
 
-extern int g_chart_zoom_modifier;
+extern int g_chart_zoom_modifier_raster;
 extern int g_chart_zoom_modifier_vector;
 
 extern int g_NMEAAPBPrecision;
 
-extern wxString g_TalkerIdText;
-extern int g_maxWPNameLength;
-
 extern bool g_bAdvanceRouteWaypointOnArrivalOnly;
 extern double g_display_size_mm;
 extern double g_config_display_size_mm;
@@ -935,7 +928,7 @@ bool ConfigMgr::SaveTemplate(wxString fileName) {
 
   conf->Write(_T ( "SkewToNorthUp" ), g_bskew_comp);
 
-  conf->Write(_T ( "ZoomDetailFactor" ), g_chart_zoom_modifier);
+  conf->Write(_T ( "ZoomDetailFactor" ), g_chart_zoom_modifier_raster);
   conf->Write(_T ( "ZoomDetailFactorVector" ), g_chart_zoom_modifier_vector);
 
   conf->Write(_T ( "SmoothPanZoom" ), g_bsmoothpanzoom);
@@ -1125,6 +1118,7 @@ bool ConfigMgr::SaveTemplate(wxString fileName) {
     conf->Write(_T ( "bShowSoundg" ), ps52plib->m_bShowSoundg);
     conf->Write(_T ( "bShowMeta" ), ps52plib->m_bShowMeta);
     conf->Write(_T ( "bUseSCAMIN" ), ps52plib->m_bUseSCAMIN);
+    conf->Write(_T ( "bUseSUPER_SCAMIN" ), ps52plib->m_bUseSUPER_SCAMIN);
     conf->Write(_T ( "bShowAtonText" ), ps52plib->m_bShowAtonText);
     conf->Write(_T ( "bShowLightDescription" ), ps52plib->m_bShowLdisText);
     conf->Write(_T ( "bExtendLightSectors" ), ps52plib->m_bExtendLightSectors);
@@ -1383,7 +1377,7 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
   CHECK_INT(_T ( "MobileTouch" ), &g_btouch);
   CHECK_INT(_T ( "ResponsiveGraphics" ), &g_bresponsive);
 
-  CHECK_INT(_T ( "ZoomDetailFactor" ), &g_chart_zoom_modifier);
+  CHECK_INT(_T ( "ZoomDetailFactor" ), &g_chart_zoom_modifier_raster);
   CHECK_INT(_T ( "ZoomDetailFactorVector" ), &g_chart_zoom_modifier_vector);
 
   CHECK_INT(_T ( "CM93DetailFactor" ), &g_cm93_zoom_factor);
@@ -1519,6 +1513,7 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
   CHECK_INT(_T ( "bRemoveLostTargets" ), &g_bRemoveLost);
   CHECK_FLT(_T ( "RemoveLost_Minutes" ), &g_RemoveLost_Mins, 1)
   CHECK_INT(_T ( "bShowCOGArrows" ), &g_bShowCOG);
+  CHECK_INT(_T ( "bSyncCogPredictors" ), &g_bSyncCogPredictors);
   CHECK_FLT(_T ( "CogArrowMinutes" ), &g_ShowCOG_Mins, 1);
   CHECK_INT(_T ( "bShowTargetTracks" ), &g_bAISShowTracks);
   CHECK_FLT(_T ( "TargetTracksMinutes" ), &g_AISShowTracks_Mins, 1)
@@ -1622,81 +1617,6 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
   conf->SetPath(_T ( "/Settings/QTFonts" ));
 #endif
 
-#if 0
-    if(conf->GetNumberOfEntries() != (unsigned int)FontMgr::Get().GetNumFonts() )
-        return false;
-
-    wxString str;
-    long dummy;
-    wxString pval;
-
-    bool bCont = conf->GetFirstEntry( str, dummy );
-    while( bCont ) {
-        conf->Read( str, &pval );
-        if(!FontMgr::Get().FindFontByConfigString(str))
-            return false;
-
-        bCont = conf->GetNextEntry( str, dummy );
-    }
-
-
-//  Tide/Current Data Sources
-    conf->SetPath( _T ( "/TideCurrentDataSources" ) );
-    if( conf->GetNumberOfEntries() != TideCurrentDataSet.GetCount())
-        return false;
-
-    if( conf->GetNumberOfEntries()){
-        wxString str, val;
-        long dummy;
-        bool bCont = conf->GetFirstEntry( str, dummy );
-        while( bCont ) {
-            conf->Read( str, &val );              // Get a file name
-            if( TideCurrentDataSet.Index(val) == wxNOT_FOUND)
-                return false;
-            bCont = conf->GetNextEntry( str, dummy );
-        }
-    }
-
-#endif
-
-#if 0
-    //    Groups
-    conf->SetPath( _T ( "/Groups" ) );
-    unsigned int group_count;
-    conf->Read( _T ( "GroupCount" ), (int *) &group_count, 0 );
-
-    if(group_count != g_pGroupArray->GetCount())
-        return false;
-
-    // Walk the array of groups in the target template
-    for( unsigned int i = 0; i < group_count; i++ ) {
-        wxString s;
-        s.Printf( _T("Group%d"), i + 1 );
-        s.Prepend( _T ( "/Groups/" ) );
-        conf->SetPath( s );
-
-        wxString t;
-        conf->Read( _T ( "GroupName" ), &t );
-
-        // Look for this group name int the active array
-        bool bfound = false;
-        ChartGroup *pGroup;
-        for(unsigned int j = 0 ; j < g_pGroupArray->GetCount() ; j++){
-            pGroup = g_pGroupArray->Item(i);
-            if(pGroup && (pGroup->m_group_name.IsSameAs(t))){
-                bfound = true;
-                break;
-            }
-        }
-
-        if(!bfound)
-            return false;
-        //TODO
-        // Here we could further check the contents of the found group.
-    }
-
-#endif
-
   conf->SetPath(_T ( "/Settings/Others" ));
 
   // Radar rings
@@ -1779,6 +1699,7 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
     CHECK_BFN(_T ( "bShowSoundg" ), ps52plib->m_bShowSoundg);
     CHECK_BFN(_T ( "bShowMeta" ), ps52plib->m_bShowMeta);
     CHECK_BFN(_T ( "bUseSCAMIN" ), ps52plib->m_bUseSCAMIN);
+    CHECK_BFN(_T ( "bUseSUPERSCAMIN" ), ps52plib->m_bUseSUPER_SCAMIN);
     CHECK_BFN(_T ( "bShowAtonText" ), ps52plib->m_bShowAtonText);
     CHECK_BFN(_T ( "bDeClutterText" ), ps52plib->m_bDeClutterText);
     CHECK_BFN(_T ( "bShowNationalText" ), ps52plib->m_bShowNationalTexts);
@@ -1835,7 +1756,7 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
     }
   }
 
-  conf->SetPath(_T ( "/MMSIProperties" ));
+  conf->SetPath(_T ( "/MmsiProperties" ));
   int iPMax = conf->GetNumberOfEntries();
   if (iPMax) {
     wxString str, val;
@@ -1847,7 +1768,7 @@ bool ConfigMgr::CheckTemplate(wxString fileName) {
 
       bool bfound = false;
       for (unsigned int j = 0; j < g_MMSI_Props_Array.GetCount(); j++) {
-        MMSIProperties *pProps = g_MMSI_Props_Array.Item(j);
+        MmsiProperties *pProps = g_MMSI_Props_Array.Item(j);
         if (pProps->Serialize().IsSameAs(val)) {
           bfound = true;
           break;
