@@ -26,26 +26,25 @@
  *
  */
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 
 #include <wx/statline.h>
 
-#include "dychart.h"
-
 #include "chcanv.h"
 #include "MUIBar.h"
 #include "OCPNPlatform.h"
 #include "CanvasOptions.h"
+#include "DetailSlider.h"
+#include "GoToPositionDialog.h"
 #include "styles.h"
 #include "navutil.h"
-
-#ifdef ocpnUSE_SVG
-#include "wxSVG/svg.h"
-#endif  // ocpnUSE_SVG
+#include "svg_utils.h"
+#include "idents.h"
+#include "color_handler.h"
 
 #ifdef __OCPN__ANDROID__
 #include "androidUTIL.h"
@@ -61,24 +60,6 @@ extern ChartCanvas* g_focusCanvas;
 extern ocpnStyle::StyleManager* g_StyleManager;
 extern bool g_bShowMuiZoomButtons;
 
-//  Helper utilities
-static wxBitmap LoadSVG(const wxString filename, unsigned int width,
-                        unsigned int height) {
-#ifdef ocpnUSE_SVG
-#ifdef __OCPN__ANDROID__
-  return loadAndroidSVG(filename, width, height);
-#else
-  wxSVGDocument svgDoc;
-  if (svgDoc.Load(filename))
-    return wxBitmap(svgDoc.Render(width, height, NULL, true, true));
-  else
-    return wxBitmap(width, height);
-#endif
-#else
-  return wxBitmap(width, height);
-#endif  // ocpnUSE_SVG
-}
-
 double getValue(int animationType, double t);
 
 //  Helper classes
@@ -555,6 +536,10 @@ MUIBar::MUIBar(ChartCanvas* parent, int orientation, float size_factor,
   long mstyle = wxNO_BORDER | wxFRAME_NO_TASKBAR | wxFRAME_SHAPED |
                 wxFRAME_FLOAT_ON_PARENT;
 
+#ifdef __WXOSX__
+  mstyle |= wxFRAME_TOOL_WINDOW;
+#endif
+
   m_scaleFactor = size_factor;
   m_cs = (ColorScheme)-1;
 
