@@ -24,17 +24,17 @@
  **************************************************************************/
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif
 
 #include <OCPN_AUIManager.h>
-#include "chart1.h"
 #include "ocpn_plugin.h"
+#include "ocpn_frame.h"
 
 #ifdef __WXMSW__
-#include "wx/msw/wrapwin.h"
-#include "wx/msw/private.h"
-#include "wx/msw/dc.h"
+#include <wx/msw/wrapwin.h>
+#include <wx/msw/private.h>
+#include <wx/msw/dc.h>
 #endif
 
 // -- static utility functions --
