@@ -27,10 +27,12 @@
 #include "navutil.h"
 #include "georef.h"
 #include "MarkInfo.h"
+#include "own_ship.h"
 #include "routeman.h"
 #include "routemanagerdialog.h"
 #include "routeprintout.h"
 #include "chcanv.h"
+#include "navutil_base.h"
 #include "tcmgr.h"
 #include "ocpn_plugin.h"
 #include "gui_lib.h"
@@ -46,8 +48,6 @@
 
 extern wxString GetLayerName(int id);
 
-extern double gLat;
-extern double gLon;
 extern WayPointman* pWayPointMan;
 extern Routeman* g_pRouteMan;
 extern MyConfig* pConfig;
@@ -903,8 +903,8 @@ void RoutePropDlgImpl::OnRoutePropMenuSelected(wxCommandEvent& event) {
         RoutePoint* pRP = m_pRoute->GetPoint(
             static_cast<int>(reinterpret_cast<long long>(selection.GetID())));
 
-        g_pRouteMan->RemovePointFromRoute(pRP, m_pRoute, NULL);
-
+        g_pRouteMan->RemovePointFromRoute(pRP, m_pRoute, 0);
+        gFrame->InvalidateAllGL();
         UpdatePoints();
       }
       break;
@@ -1058,7 +1058,7 @@ void RoutePropDlgImpl::SplitOnButtonClick(wxCommandEvent& event) {
 
     pSelect->DeleteAllSelectableRoutePoints(m_pRoute);
     pSelect->DeleteAllSelectableRouteSegments(m_pRoute);
-    g_pRouteMan->DeleteRoute(m_pRoute);
+    g_pRouteMan->DeleteRoute(m_pRoute, NavObjectChanges::getInstance());
     pSelect->AddAllSelectableRouteSegments(m_pTail);
     pSelect->AddAllSelectableRoutePoints(m_pTail);
     pSelect->AddAllSelectableRouteSegments(m_pHead);
