@@ -25,24 +25,27 @@
 #include "config.h"
 
 #include "navutil.h"
+#include "navutil_base.h"
 #include "georef.h"
+#include "own_ship.h"
 #include "routeman.h"
+#include "routeman_gui.h"
 #include "routemanagerdialog.h"
 #include "trackprintout.h"
 #include "pluginmanager.h"
 #include "OCPNPlatform.h"
 #include "TrackPropDlg.h"
-#include "Track.h"
-#include "Route.h"
+#include "track.h"
+#include "route.h"
 #include "chcanv.h"
 #include "gui_lib.h"
+#include "ocpn_frame.h"
 
 #ifdef __OCPN__ANDROID__
 #include "androidUTIL.h"
 #endif
 
-extern double gLat, gLon;
-extern TrackList* pTrackList;
+extern std::vector<Track*> g_TrackList;
 extern ActiveTrack* g_pActiveTrack;
 extern Routeman* g_pRouteMan;
 extern Select* pSelect;
@@ -805,23 +808,26 @@ void TrackPropDlg::CreateControls(void) {
   wxBoxSizer* bSizerShowTime;
   bSizerShowTime = new wxBoxSizer(wxHORIZONTAL);
 
-  m_stShowTime = new wxStaticText(m_panelBasic, wxID_ANY, _("Time shown as"),
+  m_stShowTime = new wxStaticText(m_panel0, wxID_ANY, _("Time shown as"),
                                   wxDefaultPosition, wxDefaultSize, 0);
   // m_stShowTime->Wrap( -1 );
   bSizerShowTime->Add(m_stShowTime, 0, wxALL, 5);
 
-  m_rbShowTimeUTC = new wxRadioButton(m_panelBasic, wxID_ANY, _("UTC"),
+  m_rbShowTimeUTC = new wxRadioButton(m_panel0, wxID_ANY, _("UTC"),
                                       wxDefaultPosition, wxDefaultSize, 0);
-  bSizerShowTime->Add(m_rbShowTimeUTC, 0, 0, 5);
+  bSizerShowTime->Add(m_rbShowTimeUTC, 0,
+       wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5);
 
-  m_rbShowTimePC = new wxRadioButton(m_panelBasic, wxID_ANY, _("Local @ PC"),
+  m_rbShowTimePC = new wxRadioButton(m_panel0, wxID_ANY, _("Local @ PC"),
                                      wxDefaultPosition, wxDefaultSize, 0);
-  bSizerShowTime->Add(m_rbShowTimePC, 0, 0, 5);
+  bSizerShowTime->Add(m_rbShowTimePC, 0,
+       wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5);
 
   m_rbShowTimeLocal =
-      new wxRadioButton(m_panelBasic, wxID_ANY, _("LMT @ Track Start"),
+      new wxRadioButton(m_panel0, wxID_ANY, _("LMT @ Track Start"),
                         wxDefaultPosition, wxDefaultSize, 0);
-  bSizerShowTime->Add(m_rbShowTimeLocal, 0, 0, 5);
+  bSizerShowTime->Add(m_rbShowTimeLocal, 0,
+       wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5);
 
   m_rbShowTimePC->SetValue(true);
 
@@ -1250,9 +1256,7 @@ bool TrackPropDlg::IsThisTrackExtendable() {
     return false;
   }
 
-  wxTrackListNode* track_node = pTrackList->GetFirst();
-  while (track_node) {
-    Track* ptrack = track_node->GetData();
+  for (Track* ptrack : g_TrackList) {
     if (ptrack->IsVisible() && (ptrack->m_GUID != m_pTrack->m_GUID)) {
       TrackPoint* track_node = ptrack->GetLastPoint();
       if (track_node) {
@@ -1267,7 +1271,6 @@ bool TrackPropDlg::IsThisTrackExtendable() {
         }
       }
     }
-    track_node = track_node->GetNext();  // next track
   }
   if (m_pExtendTrack) {
     return (!m_pExtendTrack->m_bIsInLayer);
@@ -1288,7 +1291,7 @@ void TrackPropDlg::OnExtendBtnClick(wxCommandEvent& event) {
     m_pExtendTrack->Clone(m_pTrack, begin, m_pTrack->GetnPoints(), _("_plus"));
     pSelect->AddAllSelectableTrackSegments(m_pExtendTrack);
     pSelect->DeleteAllSelectableTrackSegments(m_pTrack);
-    g_pRouteMan->DeleteTrack(m_pTrack);
+    RoutemanGui(*g_pRouteMan).DeleteTrack(m_pTrack);
 
     SetTrackAndUpdate(m_pExtendTrack);
     UpdateProperties();
@@ -1311,16 +1314,16 @@ void TrackPropDlg::OnSplitBtnClick(wxCommandEvent& event) {
     Track* pTail = new Track();
     pHead->Clone(m_pTrack, 0, m_nSelected - 1, _("_A"));
     pTail->Clone(m_pTrack, m_nSelected - 1, m_pTrack->GetnPoints(), _("_B"));
-    pTrackList->Append(pHead);
+    g_TrackList.push_back(pHead);
     pConfig->AddNewTrack(pHead);
 
-    pTrackList->Append(pTail);
+    g_TrackList.push_back(pTail);
     pConfig->AddNewTrack(pTail);
 
     pConfig->DeleteConfigTrack(m_pTrack);
 
     pSelect->DeleteAllSelectableTrackSegments(m_pTrack);
-    g_pRouteMan->DeleteTrack(m_pTrack);
+    RoutemanGui(*g_pRouteMan).DeleteTrack(m_pTrack);
     pSelect->AddAllSelectableTrackSegments(pTail);
     pSelect->AddAllSelectableTrackSegments(pHead);
 
@@ -1449,8 +1452,7 @@ void TrackPropDlg::OnToRouteBtnClick(wxCommandEvent& event) {
 
 void TrackPropDlg::OnExportBtnClick(wxCommandEvent& event) {
   wxString suggested_name = _("track");
-  TrackList list;
-  list.Append(m_pTrack);
+  std::vector<Track*> list = { m_pTrack };
   if (m_pTrack->GetName() != wxEmptyString)
     suggested_name = m_pTrack->GetName();
   ExportGPXTracks(this, &list, suggested_name);
@@ -1734,17 +1736,9 @@ void TrackPropDlg::OnOKBtnClick(wxCommandEvent& event) {
   //    Look in the track list to be sure the track is still available
   //    (May have been deleted by RouteManagerDialog...)
 
-  bool b_found_track = false;
-  wxTrackListNode* node = pTrackList->GetFirst();
-  while (node) {
-    Track* ptrack = node->GetData();
-
-    if (ptrack == m_pTrack) {
-      b_found_track = true;
-      break;
-    }
-    node = node->GetNext();
-  }
+  bool b_found_track =
+    std::find(g_TrackList.begin(), g_TrackList.end(), m_pTrack) !=
+    g_TrackList.end();
 
   if (b_found_track) {
     SaveChanges();  // write changes to globals and update config
@@ -1764,17 +1758,9 @@ void TrackPropDlg::OnOKBtnClick(wxCommandEvent& event) {
 }
 
 void TrackPropDlg::OnCancelBtnClick(wxCommandEvent& event) {
-  bool b_found_track = false;
-  wxTrackListNode* node = pTrackList->GetFirst();
-  while (node) {
-    Track* ptrack = node->GetData();
-
-    if (ptrack == m_pTrack) {
-      b_found_track = true;
-      break;
-    }
-    node = node->GetNext();
-  }
+  bool b_found_track =
+    std::find(g_TrackList.begin(), g_TrackList.end(), m_pTrack) !=
+    g_TrackList.end();
 
   if (b_found_track) m_pTrack->ClearHighlights();
 
