@@ -34,10 +34,10 @@
 #include <wx/textctrl.h>
 
 #include "cat_settings.h"
-#include "config_var.h"
+#include "observable_globvar.h"
 #include "ocpn_utils.h"
 #include "plugin_cache.h"
-#include "PluginHandler.h"
+#include "plugin_handler.h"
 
 extern wxString g_catalog_channel;
 extern wxString g_catalog_custom_url;
@@ -69,7 +69,7 @@ private:
   wxStaticText* m_selected;
 
   void OnChoice(wxCommandEvent&) {
-    ocpn::GlobalVar<wxString> compat_os(&g_compatOS);
+    GlobalVar<wxString> compat_os(&g_compatOS);
     if (GetSelection() == 0) {
       // "Select new flavour"
       return;
@@ -77,14 +77,14 @@ private:
     if (GetSelection() == 1) {
       // "Default Setting"
       g_compatOsVersion = "";
-      compat_os.set("");
+      compat_os.Set("");
       auto newOS = CompatOs::getInstance();
       m_selected->SetLabel(newOS->name() + ":" + newOS->version());
     } else {
       auto current = GetString(GetSelection());
       auto os = ocpn::split(current, " ")[0];
       m_selected->SetLabel(os);
-      compat_os.set(ocpn::split(os.c_str(), ":")[0]);
+      compat_os.Set(ocpn::split(os.c_str(), ":")[0]);
       g_compatOsVersion = ocpn::split(os.c_str(), ":")[1];
     }
   }
@@ -114,6 +114,10 @@ public:
     for (const auto& l : labels) wxLabels.Add(l);
     Create(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxLabels);
 
+#ifdef __OCPN__ANDROID__
+    SetMinSize(wxSize(12 * GetCharWidth(), -1));
+#endif
+
     m_custom_ctrl->Enable(false);
     for (auto l = labels.begin(); l != labels.end(); l++) {
       if (g_catalog_channel == *l) {
@@ -140,8 +144,8 @@ private:
     } else {
       m_custom_ctrl->Hide();
     }
-    ocpn::GlobalVar<wxString> catalog(&g_catalog_channel);
-    catalog.set(selected);
+    GlobalVar<wxString> catalog(&g_catalog_channel);
+    catalog.Set(selected);
     Layout();
   }
 };
@@ -160,11 +164,10 @@ class CatalogSizer : public wxStaticBoxSizer {
 public:
   CatalogSizer(wxWindow* parent)
       : wxStaticBoxSizer(wxHORIZONTAL, parent, _("Active catalog")) {
-    auto flags = wxSizerFlags().Border();
-    Add(new wxStaticText(parent, wxID_ANY, _("Select plugin catalog")),
-        flags.Center());
+    auto flags = wxSizerFlags().Border(wxALL, parent->GetCharWidth());
+    Add(new wxStaticText(parent, wxID_ANY, _("Select plugin catalog")), flags);
     auto custom_ctrl = new CustomCatalogCtrl(parent);
-    Add(new CatalogChoice(parent, custom_ctrl), flags.Expand());
+    Add(new CatalogChoice(parent, custom_ctrl), flags);
     Add(custom_ctrl, flags.Expand().Proportion(1));
     Layout();
   }
@@ -224,7 +227,8 @@ private:
 class ButtonsSizer : public wxStdDialogButtonSizer {
 public:
   ButtonsSizer(wxWindow* parent) : wxStdDialogButtonSizer() {
-    auto button = new wxButton(parent, wxID_OK, "LongLabel", wxDefaultPosition, wxSize(10 * parent->GetCharWidth(), -1));
+    auto button = new wxButton(parent, wxID_OK, "LongLabel", wxDefaultPosition,
+                               wxSize(10 * parent->GetCharWidth(), -1));
     button->SetLabel(_("Done"));
     SetAffirmativeButton(button);
     Realize();
@@ -236,7 +240,6 @@ CatalogSettingsDialog::CatalogSettingsDialog(wxWindow* parent)
     : wxDialog(parent, wxID_ANY, _("Plugin Catalog Settings"),
                wxDefaultPosition, wxDefaultSize,
                wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER) {
-
 #ifdef __OCPN__ANDROID__
   SetBackgroundColour(wxColour(0x7c, 0xb0, 0xe9));  // light blue
 #endif
