@@ -40,10 +40,10 @@
 
 #include "catalog_handler.h"
 #include "catalog_mgr.h"
-#include "Downloader.h"
+#include "downloader.h"
 #include "ocpn_utils.h"
 #include "OCPNPlatform.h"
-#include "PluginHandler.h"
+#include "plugin_handler.h"
 #include "download_mgr.h"
 
 extern OCPNPlatform* g_Platform;
