@@ -24,24 +24,26 @@
  **************************************************************************/
 
 // For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 
 #include <wx/stopwatch.h>
 #include <wx/regex.h>
-#include "wx/tokenzr.h"
-#include "wx/dir.h"
+#include <wx/tokenzr.h>
+#include <wx/dir.h>
+
+#include "dychart.h"
 
 #include "config.h"
 #include "chartdb.h"
 #include "chartimg.h"
-#include "chart1.h"
 #include "thumbwin.h"
 #include "mbtiles.h"
 #include "CanvasConfig.h"
+#include "ocpn_frame.h"  //FIXME (dave) LoadS57
 #ifdef __OCPN__ANDROID__
  #include "androidUTIL.h"
 #endif
