@@ -24,9 +24,9 @@
  ***************************************************************************
  *
  */
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 #include "config.h"
 #include "ocpn_types.h"
@@ -34,8 +34,8 @@
 #include "chcanv.h"
 #include "styles.h"
 
-#include "dychart.h"
 #include "glChartCanvas.h"
+#include "ocpn_frame.h"     // FIXME (dave) colorschemes
 
 extern ocpnStyle::StyleManager* g_StyleManager;
 extern bool bGPSValid;
@@ -43,6 +43,10 @@ extern bool g_bSatValid;
 extern int g_SatsInView;
 extern bool g_bopengl;
 
+#ifndef GL_RGBA8
+#define GL_RGBA8 0x8058
+#endif
+
 ocpnCompass::ocpnCompass(ChartCanvas* parent, bool bShowGPS) {
   m_parent = parent;
   m_bshowGPS = bShowGPS;
@@ -63,8 +67,9 @@ ocpnCompass::ocpnCompass(ChartCanvas* parent, bool bShowGPS) {
                  style->GetCompassBottomMargin());
 
 #ifdef ocpnUSE_GL
-  texobj = 0;
+  m_texobj = 0;
 #endif
+  m_texOK = false;
 
   m_scale = 1.0;
   m_cs = GLOBAL_COLOR_SCHEME_RGB;
@@ -72,9 +77,9 @@ ocpnCompass::ocpnCompass(ChartCanvas* parent, bool bShowGPS) {
 
 ocpnCompass::~ocpnCompass() {
 #ifdef ocpnUSE_GL
-  if (texobj) {
-    glDeleteTextures(1, &texobj);
-    texobj = 0;
+  if (m_texobj) {
+    glDeleteTextures(1, &m_texobj);
+    m_texobj = 0;
   }
 #endif
 
@@ -83,14 +88,19 @@ ocpnCompass::~ocpnCompass() {
 
 void ocpnCompass::Paint(ocpnDC& dc) {
   if (m_shown && m_StatBmp.IsOk()) {
-#if defined(ocpnUSE_GLES) || \
-    defined(                 \
-        ocpnUSE_GL)  // GLES does not do ocpnDC::DrawBitmap(), so use texture
-    if (g_bopengl && texobj) {
-      glBindTexture(GL_TEXTURE_2D, texobj);
+#if defined(ocpnUSE_GLES) || defined(ocpnUSE_GL)
+    if (!m_texobj){
+      // The glContext is known active here,
+      // so safe to create a texture.
+      glGenTextures(1, &m_texobj);
+      CreateTexture();
+    }
+
+    if (g_bopengl && m_texobj /*&& m_texOK*/) {
+      glBindTexture(GL_TEXTURE_2D, m_texobj);
       glEnable(GL_TEXTURE_2D);
 
-#ifdef USE_ANDROID_GLES2
+#if defined(USE_ANDROID_GLES2) || defined(ocpnUSE_GLSL)
       float coords[8];
       float uv[8];
 
@@ -114,7 +124,7 @@ void ocpnCompass::Paint(ocpnDC& dc) {
       coords[6] = m_rect.x;
       coords[7] = m_rect.y + m_rect.height;
 
-      m_parent->GetglCanvas()->RenderTextures(coords, uv, 4,
+      m_parent->GetglCanvas()->RenderTextures(dc, coords, uv, 4,
                                               m_parent->GetpVP());
 #else
 
@@ -183,22 +193,16 @@ void ocpnCompass::SetColorScheme(ColorScheme cs) {
 }
 
 void ocpnCompass::UpdateStatus(bool bnew) {
-  if (bnew) {
+  if (bnew)
     m_lastgpsIconName.Clear();  // force an update to occur
 
-    //  We clear the texture so that any onPaint method will not use a stale
-    //  texture
-#ifdef ocpnUSE_GLES
-    if (g_bopengl) {
-      if (texobj) {
-        glDeleteTextures(1, &texobj);
-        texobj = 0;
-      }
-    }
-#endif
-  }
-
   CreateBmp(bnew);
+
+#ifdef ocpnUSE_GL
+  if (g_bopengl && m_texobj)
+    CreateTexture();
+#endif
+
 }
 
 void ocpnCompass::SetScaleFactor(float factor) {
@@ -245,7 +249,7 @@ void ocpnCompass::SetScaleFactor(float factor) {
 }
 
 void ocpnCompass::CreateBmp(bool newColorScheme) {
-  if (!m_shown) return;
+  //if (!m_shown) return;
 
   wxString gpsIconName;
   ocpnStyle::Style* style = g_StyleManager->GetCurrentStyle();
@@ -314,7 +318,7 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
 
   if (fabs(m_rose_angle - rose_angle) > .1) b_need_refresh = true;
 
-  if (!b_need_refresh) return;
+  //if (!b_need_refresh) return;
 
   int width = compassBg.GetWidth();
   if (m_bshowGPS) width += gpsBg.GetWidth() + leftmargin;
@@ -328,7 +332,7 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
   m_rect.width = m_StatBmp.GetWidth();
   m_rect.height = m_StatBmp.GetHeight();
 
-  if (!m_StatBmp.IsOk()) return;
+  //if (!m_StatBmp.IsOk()) return;
 
   m_MaskBmp = wxBitmap(m_StatBmp.GetWidth(), m_StatBmp.GetHeight());
   if (style->marginsInvisible) {
@@ -351,7 +355,7 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
                              radius);
     sdc.SelectObject(wxNullBitmap);
   }
-#ifndef ocpnUSE_GLES
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
   m_StatBmp.SetMask(new wxMask(m_MaskBmp, *wxWHITE));
 #endif
 
@@ -438,8 +442,11 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
 
     m_lastgpsIconName = gpsIconName;
   }
+}
 
-#if defined(ocpnUSE_GLES)  // GLES does not do ocpnDC::DrawBitmap(), so use
+void ocpnCompass::CreateTexture() {
+#if defined(USE_ANDROID_GLES2) || defined(ocpnUSE_GLSL)
+  // GLES does not do ocpnDC::DrawBitmap(), so use
                            // texture
   if (g_bopengl) {
     wxImage image = m_StatBmp.ConvertToImage();
@@ -482,7 +489,7 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
     m_tex_h = height_pot;
 
     GLuint format = GL_RGBA;
-    GLuint internalformat = format;
+    GLuint internalformat = GL_RGBA8; //format;
     int stride = 4;
 
     if (imgdata) {
@@ -501,13 +508,7 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
         }
       }
 
-      if (texobj) {
-        glDeleteTextures(1, &texobj);
-        texobj = 0;
-      }
-
-      glGenTextures(1, &texobj);
-      glBindTexture(GL_TEXTURE_2D, texobj);
+      glBindTexture(GL_TEXTURE_2D, m_texobj);
 
       glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
       glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
@@ -519,6 +520,84 @@ void ocpnCompass::CreateBmp(bool newColorScheme) {
                    format, GL_UNSIGNED_BYTE, teximage);
 
       free(teximage);
+      glBindTexture(GL_TEXTURE_2D, 0);
+      m_texOK = true;
+    }
+  }
+#endif
+}
+
+void ocpnCompass::UpdateTexture() {
+#if defined(USE_ANDROID_GLES2) || defined(ocpnUSE_GLSL)
+  // GLES does not do ocpnDC::DrawBitmap(), so use
+                           // texture
+  if (g_bopengl) {
+    wxImage image = m_StatBmp.ConvertToImage();
+    unsigned char* imgdata = image.GetData();
+    unsigned char* imgalpha = image.GetAlpha();
+    m_tex_w = image.GetWidth();
+    m_tex_h = image.GetHeight();
+    m_image_width = m_tex_w;
+    m_image_height = m_tex_h;
+
+    // Make it POT
+    int width_pot = m_tex_w;
+    int height_pot = m_tex_h;
+
+    int xp = image.GetWidth();
+    if (((xp != 0) && !(xp & (xp - 1))))  // detect POT
+      width_pot = xp;
+    else {
+      int a = 0;
+      while (xp) {
+        xp = xp >> 1;
+        a++;
+      }
+      width_pot = 1 << a;
+    }
+
+    xp = image.GetHeight();
+    if (((xp != 0) && !(xp & (xp - 1))))
+      height_pot = xp;
+    else {
+      int a = 0;
+      while (xp) {
+        xp = xp >> 1;
+        a++;
+      }
+      height_pot = 1 << a;
+    }
+
+    m_tex_w = width_pot;
+    m_tex_h = height_pot;
+
+    GLuint format = GL_RGBA;
+    GLuint internalformat = GL_RGBA8; //format;
+    int stride = 4;
+
+    if (imgdata) {
+      unsigned char* teximage =
+          (unsigned char*)malloc(stride * m_tex_w * m_tex_h);
+
+      for (int i = 0; i < m_image_height; i++) {
+        for (int j = 0; j < m_image_width; j++) {
+          int s = (i * 3 * m_image_width) + (j * 3);
+          int d = (i * stride * m_tex_w) + (j * stride);
+
+          teximage[d + 0] = imgdata[s + 0];
+          teximage[d + 1] = imgdata[s + 1];
+          teximage[d + 2] = imgdata[s + 2];
+          teximage[d + 3] = 255;
+        }
+      }
+
+      glBindTexture(GL_TEXTURE_2D, m_texobj);
+      glEnable(GL_TEXTURE_2D);
+
+      glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, m_tex_w, m_tex_h, format, GL_UNSIGNED_BYTE, teximage);
+
+      free(teximage);
+      glBindTexture(GL_TEXTURE_2D, 0);
     }
   }
 #endif
