@@ -27,27 +27,29 @@
  *
  */
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 
-#include "dychart.h"
-
 #include <stdlib.h>
 #include <math.h>
 #include <time.h>
-#include "wx/datetime.h"
+#include <wx/datetime.h>
 
 #include "gui_lib.h"
 #include "concanv.h"
 #include "styles.h"
 #include "routeman.h"
 #include "navutil.h"
+#include "navutil_base.h"
 #include "FontMgr.h"
 #include "wx28compat.h"
-#include "Route.h"
+#include "route.h"
+#include "ocpn_frame.h"
+#include "OCPNPlatform.h"
+#include "ocpn_plugin.h"
 
 extern Routeman* g_pRouteMan;
 extern MyFrame* gFrame;
@@ -55,6 +57,7 @@ extern bool g_bShowActiveRouteHighway;
 extern double gCog;
 extern double gSog;
 extern bool g_bShowTrue, g_bShowMag;
+extern BasePlatform* g_BasePlatform;
 
 bool g_bShowRouteTotal;
 
@@ -83,6 +86,10 @@ ConsoleCanvas::ConsoleCanvas(wxWindow* frame) {
 
   long style = wxSIMPLE_BORDER | wxCLIP_CHILDREN | wxFRAME_FLOAT_ON_PARENT;
 
+#ifdef __WXMSW__
+  style |= wxFRAME_NO_TASKBAR;
+#endif
+
   wxFrame::Create(frame, wxID_ANY, _T(""), wxDefaultPosition, wxDefaultSize,
                   style);
 
@@ -396,7 +403,7 @@ void ConsoleCanvas::UpdateRouteData() {
 
         if (speed > 0.) {
           // Show date, e.g. Feb 15, if TTG > 24 h
-          seta = tttg_sec > SECONDS_PER_DAY ? eta.Format(_T("%e/%m %H:%M"))
+          seta = tttg_sec > SECONDS_PER_DAY ? eta.Format(_T("%d/%m %H:%M"))
                                             : eta.Format(_T("%H:%M"));
         } else {
           seta = _T("---");
@@ -513,6 +520,10 @@ void AnnunText::CalculateMinSize(void) {
   if (m_pvalueFont)
     GetTextExtent(_T("123.4567"), &wv, &hv, NULL, NULL, m_pvalueFont);
 
+   double pdifactor = g_BasePlatform->GetDisplayDIPMult(gFrame);
+   wl *= pdifactor; hl *= pdifactor;
+   wv *= pdifactor; hv *= pdifactor;
+
   wxSize min;
   min.x = wl + wv;
 
@@ -524,6 +535,13 @@ void AnnunText::CalculateMinSize(void) {
   min.y = (int)((hl + hv) * 1.2);
 
   SetMinSize(min);
+
+  //resize background to the necessary size
+  ocpnStyle::Style* style = g_StyleManager->GetCurrentStyle();
+  if (style->consoleTextBackground.IsOk()) {
+    wxImage img = style->consoleTextBackground.ConvertToImage();
+    style->consoleTextBackground = wxBitmap(img.Rescale(min.x, min.y));
+  }
 }
 
 void AnnunText::SetColorScheme(ColorScheme cs) {
@@ -536,8 +554,19 @@ void AnnunText::SetColorScheme(ColorScheme cs) {
 }
 
 void AnnunText::RefreshFonts() {
-  m_plabelFont = FontMgr::Get().GetFont(m_LegendTextElement);
-  m_pvalueFont = FontMgr::Get().GetFont(m_ValueTextElement);
+  wxFont *pl = FontMgr::Get().GetFont(m_LegendTextElement);
+  m_plabelFont = FontMgr::Get().FindOrCreateFont(
+      pl->GetPointSize() / OCPN_GetWinDIPScaleFactor(),
+      pl->GetFamily(), pl->GetStyle(),
+      pl->GetWeight(), FALSE,
+      pl->GetFaceName());
+
+  wxFont *pv = FontMgr::Get().GetFont(m_ValueTextElement);
+  m_pvalueFont = FontMgr::Get().FindOrCreateFont(
+      pv->GetPointSize() / OCPN_GetWinDIPScaleFactor(),
+      pv->GetFamily(), pv->GetStyle(),
+      pv->GetWeight(), FALSE,
+      pv->GetFaceName());
 
   m_legend_color = FontMgr::Get().GetFontColor(_("Console Legend"));
   m_val_color = FontMgr::Get().GetFontColor(_("Console Value"));
