@@ -29,6 +29,12 @@
 #include <wx/wx.h>
 #include <wx/thread.h>
 
+#if defined(__OCPN__ANDROID__)
+#include <GLES2/gl2.h>
+#elif defined(__WXQT__) || defined(__WXGTK__)
+#include <GL/glew.h>
+#endif
+
 #include "dychart.h"
 #include "viewport.h"
 #include "glTexCache.h"
@@ -44,6 +50,8 @@
 #include "FontMgr.h"
 #include "mipmap/mipmap.h"
 #include "gui_lib.h"
+#include "ocpn_frame.h"
+#include "own_ship.h"
 
 #ifndef GL_ETC1_RGB8_OES
 #define GL_ETC1_RGB8_OES 0x8D64
@@ -59,8 +67,6 @@ WX_DEFINE_LIST(ProgressInfoList);
 
 WX_DEFINE_ARRAY_PTR(ChartCanvas *, arrayofCanvasPtr);
 
-extern double gLat, gLon, gCog, gSog, gHdt;
-
 extern int g_mipmap_max_level;
 extern GLuint g_raster_format;
 extern int g_memCacheLimit;
@@ -78,7 +84,6 @@ extern arrayofCanvasPtr g_canvasArray;
 extern OCPNPlatform *g_Platform;
 extern ColorScheme global_color_scheme;
 
-extern PFNGLGETCOMPRESSEDTEXIMAGEPROC s_glGetCompressedTexImage;
 extern bool GetMemoryStatus(int *mem_total, int *mem_used);
 
 bool bthread_debug;
@@ -244,7 +249,6 @@ static void CompressDataETC(const unsigned char *data, int dim, int size,
 
 static bool CompressUsingGPU(const unsigned char *data, int dim, int size,
                              unsigned char *tex_data, int level, bool inplace) {
-  if (!s_glGetCompressedTexImage) return false;
 #ifndef USE_ANDROID_GLES2
 
   GLuint comp_tex;
@@ -272,7 +276,7 @@ static bool CompressUsingGPU(const unsigned char *data, int dim, int size,
     if (compressedSize != size) return false;
 
     // Read back the compressed texture.
-    s_glGetCompressedTexImage(GL_TEXTURE_2D, level, tex_data);
+    glGetCompressedTexImage(GL_TEXTURE_2D, level, tex_data);
   }
 
   if (!inplace) glDeleteTextures(1, &comp_tex);
@@ -742,6 +746,10 @@ glTextureManager::glTextureManager() {
 glTextureManager::~glTextureManager() {
   //    ClearAllRasterTextures();
   ClearJobList();
+  for (int i = 0; i < m_max_jobs; i++) {
+    delete(progList[i]);
+  }
+  progList.Clear();
 }
 
 #define NBAR_LENGTH 40
