@@ -31,23 +31,34 @@
  *
  */
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif
 
 #include <wx/file.h>
 
 #include "dychart.h"
 
+// #if defined(__OCPN__ANDROID__)
+// #include <GLES2/gl2.h>
+// #elif defined(__WXQT__) || defined(__WXGTK__)
+// #include <GL/glew.h>
+// //#define GL_GLEXT_PROTOTYPES
+// //#include <GL/gl.h>
+// //#include <GL/glext.h>
+// #endif
+
+#include "ocpndc.h"
+
 #ifdef ocpnUSE_GL
 #include "glChartCanvas.h"
 #endif
 
 #include "gshhs.h"
 #include "chartbase.h"  // for projections
-#include "wx28compat.h"
+#include "shaders.h"
 
 #ifdef __WXMSW__
 #define __CALL_CONVENTION  //__stdcall
@@ -55,24 +66,20 @@
 #define __CALL_CONVENTION
 #endif
 
-#ifdef USE_ANDROID_GLES2
-#include <GLES2/gl2.h>
 #include "linmath.h"
-#endif
-
-// typedef void (APIENTRY * PFNGLBINDBUFFERPROC) (GLenum target, GLuint buffer);
 
 extern wxString gWorldMapLocation;
 
-#ifdef USE_ANDROID_GLES2
+#if defined(USE_ANDROID_GLES2) || defined(ocpnUSE_GLSL)
 static const GLchar *vertex_shader_source =
     "attribute vec2 position;\n"
     "uniform mat4 MVMatrix;\n"
+    "uniform mat4 TransformMatrix;\n"
     "uniform vec4 color;\n"
     "varying vec4 fragColor;\n"
     "void main() {\n"
     "   fragColor = color;\n"
-    "   gl_Position = MVMatrix * vec4(position, 0.0, 1.0);\n"
+    "   gl_Position = MVMatrix * TransformMatrix * vec4(position, 0.0, 1.0);\n"
     "}\n";
 
 static const GLchar *fragment_shader_source =
@@ -93,9 +100,11 @@ static const GLfloat vertices3[] = {
 enum Consts { INFOLOG_LEN = 512 };
 GLchar infoLog[INFOLOG_LEN];
 GLint fragment_shader;
-GLint shader_program;
+//GLint shader_program;
 GLint success;
 GLint vertex_shader;
+
+extern GLint color_tri_shader_program;
 #endif
 
 //-------------------------------------------------------------------------
@@ -394,7 +403,7 @@ void __CALL_CONVENTION gshhsbeginCallback(GLenum type) {
 
 void __CALL_CONVENTION gshhsendCallback() {}
 
-void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
+void GshhsPolyCell::DrawPolygonFilledGL(ocpnDC &pnt, contour_list *p, float_2Dpt **pv,
                                         int *pvc, ViewPort &vp,
                                         wxColor const &color, bool idl) {
   if (!p->size())  // size of 0 is very common, exit early
@@ -441,11 +450,8 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
             // that have a discontiguous date line
 
             if (idl && ccp.x == 180) {
-              if (vp.m_projection_type == PROJECTION_MERCATOR ||
-                  vp.m_projection_type == PROJECTION_EQUIRECTANGULAR)
-                q.m_x -=
-                    40058986 * 4096.0;  // 360 degrees in normalized viewport
-              else
+              if (vp.m_projection_type != PROJECTION_MERCATOR &&
+                  vp.m_projection_type != PROJECTION_EQUIRECTANGULAR)
                 q.m_x -= 360;  // lat/lon coordinates
             }
           }
@@ -477,8 +483,9 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
     g_pv.clear();
   }
 
-#ifdef USE_ANDROID_GLES2
+#if defined(USE_ANDROID_GLES2) || defined(ocpnUSE_GLSL)
 
+#if 0
   // Are the shaders ready?
   if (!vertex_shader) {
     /* Vertex shader */
@@ -516,7 +523,7 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
       printf("ERROR::SHADER::PROGRAM::LINKING_FAILED\n%s\n", infoLog);
     }
   }
-
+#endif
   GLuint vbo = 0;
 
   //  Build the shader viewport transform matrix
@@ -527,16 +534,21 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
   mat4x4_translate_in_place(mvp, -vp.pix_width / 2, vp.pix_height / 2, 0);
 
   if (glChartCanvas::HasNormalizedViewPort(vp)) {
-    GLint pos = glGetAttribLocation(shader_program, "position");
+#if 0
+    GLint pos = glGetAttribLocation(color_tri_shader_program, "position");
     glVertexAttribPointer(pos, 2, GL_FLOAT, GL_FALSE, 2 * sizeof(float), *pv);
     glEnableVertexAttribArray(pos);
 
     // FIXME        glUniformMatrix4fv( matloc, 1, GL_FALSE, (const
     // GLfloat*)vp.vp_transform);
+    mat4x4 m;
+    mat4x4_identity(m);
+    GLint tmatloc = glGetUniformLocation(color_tri_shader_program, "TransformMatrix");
+    glUniformMatrix4fv(tmatloc, 1, GL_FALSE, (const GLfloat*)m);
 
-    glUseProgram(shader_program);
+    glUseProgram(color_tri_shader_program);
     glDrawArrays(GL_TRIANGLES, 0, *pvc);
-
+#endif
   } else {
     float *pvt = new float[2 * (*pvc)];
     for (int i = 0; i < *pvc; i++) {
@@ -546,58 +558,27 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
       pvt[(i * 2) + 1] = q.m_y;
     }
 
-    glUseProgram(shader_program);
-
-    GLint pos = glGetAttribLocation(shader_program, "position");
-    glVertexAttribPointer(pos, 2, GL_FLOAT, GL_FALSE, 2 * sizeof(float), pvt);
-    glEnableVertexAttribArray(pos);
-
-    //         mat4x4 m, mvp;
-    //         mat4x4_identity(m);
-    //         mat4x4_scale_aniso(mvp, m, 2.0 / (float)vp.pix_width, -2.0 /
-    //         (float)vp.pix_height, 1.0); mat4x4_translate_in_place(mvp,
-    //         (float)-vp.pix_width/2, (float)-vp.pix_height/2, 0);
-    //        glUniformMatrix4fv( matloc, 1, GL_FALSE, (const GLfloat*)mvp);
-
-    GLint matloc = glGetUniformLocation(shader_program, "MVMatrix");
-    glUniformMatrix4fv(matloc, 1, GL_FALSE, (const GLfloat *)vp.vp_transform);
+    GLShaderProgram *shader = pcolor_tri_shader_program[pnt.m_canvasIndex];
+    shader->Bind();
 
     float colorv[4];
     colorv[0] = color.Red() / float(256);
     colorv[1] = color.Green() / float(256);
     colorv[2] = color.Blue() / float(256);
     colorv[3] = 1.0;
+    shader->SetUniform4fv("color", colorv);
 
-    GLint colloc = glGetUniformLocation(shader_program, "color");
-    glUniform4fv(colloc, 1, colorv);
-
-    // qDebug() << "colortri" << matloc << colloc;
+    shader->SetAttributePointerf("position", pvt);
 
     glDrawArrays(GL_TRIANGLES, 0, *pvc);
+
     delete[] pvt;
     glDeleteBuffers(1, &vbo);
+    shader->UnBind();
   }
 
+
 #else
-  glColor3ub(color.Red(), color.Green(), color.Blue());
-
-  if (glChartCanvas::HasNormalizedViewPort(vp)) {
-    glVertexPointer(2, GL_FLOAT, 2 * sizeof(float), *pv);
-    glDrawArrays(GL_TRIANGLES, 0, *pvc);
-  } else {
-    float_2Dpt *pvt = new float_2Dpt[*pvc];
-    for (int i = 0; i < *pvc; i++) {
-      float_2Dpt *pc = *pv + i;
-      wxPoint2DDouble q = vp.GetDoublePixFromLL(pc->y, pc->x);
-      pvt[i].x = q.m_y;
-      pvt[i].y = q.m_x;
-    }
-
-    glVertexPointer(2, GL_FLOAT, 2 * sizeof(float), pvt);
-    glDrawArrays(GL_TRIANGLES, 0, *pvc);
-
-    delete[] pvt;
-  }
 #endif
 }
 #endif  //#ifdef ocpnUSE_GL
@@ -605,14 +586,14 @@ void GshhsPolyCell::DrawPolygonFilledGL(contour_list *p, float_2Dpt **pv,
 #define DRAW_POLY_FILLED(POLY, COL) \
   if (POLY) DrawPolygonFilled(pnt, POLY, dx, vp, COL);
 #define DRAW_POLY_FILLED_GL(NUM, COL) \
-  DrawPolygonFilledGL(&poly##NUM, &polyv[NUM], &polyc[NUM], vp, COL, idl);
+  DrawPolygonFilledGL(pnt,&poly##NUM, &polyv[NUM], &polyc[NUM], vp, COL, idl);
 
 void GshhsPolyCell::drawMapPlain(ocpnDC &pnt, double dx, ViewPort &vp,
                                  wxColor seaColor, wxColor landColor,
                                  bool idl) {
 #ifdef ocpnUSE_GL
   if (!pnt.GetDC()) {  // opengl
-#ifndef USE_ANDROID_GLES2
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
 #define NORM_FACTOR 4096.0
     if (dx && (vp.m_projection_type == PROJECTION_MERCATOR ||
                vp.m_projection_type == PROJECTION_EQUIRECTANGULAR)) {
@@ -628,7 +609,7 @@ void GshhsPolyCell::drawMapPlain(ocpnDC &pnt, double dx, ViewPort &vp,
     DRAW_POLY_FILLED_GL(4, seaColor);
     DRAW_POLY_FILLED_GL(5, landColor);
 
-#ifndef USE_ANDROID_GLES2
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
     if (dx) glPopMatrix();
 #endif
 
@@ -954,7 +935,7 @@ void GshhsPolyReader::drawGshhsPolyMapPlain(ocpnDC &pnt, ViewPort &vp,
         for (int clat = 0; clat < 180; clat++)
           if (allCells[clon][clat]) allCells[clon][clat]->ClearPolyV();
     }
-#ifndef USE_ANDROID_GLES2
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
     glEnableClientState(GL_VERTEX_ARRAY);
 
     // use a viewport that allows the vertexes to be reused over many frames
@@ -1009,7 +990,7 @@ void GshhsPolyReader::drawGshhsPolyMapPlain(ocpnDC &pnt, ViewPort &vp,
   }
 
 #ifdef ocpnUSE_GL
-#ifndef USE_ANDROID_GLES2
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
   if (!pnt.GetDC()) {  // opengl
     if (glChartCanvas::HasNormalizedViewPort(vp)) glPopMatrix();
     glDisableClientState(GL_VERTEX_ARRAY);
