@@ -29,11 +29,12 @@
 #include <wx/statbmp.h>
 
 #include "gui_lib.h"
+#include "timers.h"
 #include "FontMgr.h"
 #include "OCPNPlatform.h"
 #include "ocpn_plugin.h"
 
-#ifdef __OCPN__ANDROID__
+#ifdef __ANDROID__
 #include "androidUTIL.h"
 #include "qdebug.h"
 #endif
@@ -273,6 +274,7 @@ EVT_BUTTON(wxID_NO, OCPN_TimedHTMLMessageDialog::OnNo)
 EVT_BUTTON(wxID_CANCEL, OCPN_TimedHTMLMessageDialog::OnCancel)
 EVT_CLOSE(OCPN_TimedHTMLMessageDialog::OnClose)
 EVT_TIMER(-1, OCPN_TimedHTMLMessageDialog::OnTimer)
+EVT_HTML_LINK_CLICKED( wxID_ANY, OCPN_TimedHTMLMessageDialog::OnHtmlLinkClicked )
 END_EVENT_TABLE()
 
 OCPN_TimedHTMLMessageDialog::OCPN_TimedHTMLMessageDialog(
@@ -389,3 +391,47 @@ void OCPN_TimedHTMLMessageDialog::OnTimer(wxTimerEvent& evt) {
   else
     Hide();
 }
+
+
+//      Auto timed popup Window implementation
+
+BEGIN_EVENT_TABLE(TimedPopupWin, wxWindow)
+EVT_PAINT(TimedPopupWin::OnPaint)
+EVT_TIMER(POPUP_TIMER, TimedPopupWin::OnTimer)
+
+END_EVENT_TABLE()
+
+// Define a constructor
+TimedPopupWin::TimedPopupWin(wxWindow *parent, int timeout)
+    : wxWindow(parent, wxID_ANY, wxPoint(0, 0), wxSize(1, 1), wxNO_BORDER) {
+  m_pbm = NULL;
+
+  m_timer_timeout.SetOwner(this, POPUP_TIMER);
+  m_timeout_sec = timeout;
+  isActive = false;
+  Hide();
+}
+
+TimedPopupWin::~TimedPopupWin() { delete m_pbm; }
+void TimedPopupWin::OnTimer(wxTimerEvent &event) {
+  if (IsShown()) Hide();
+}
+
+void TimedPopupWin::SetBitmap(wxBitmap &bmp) {
+  delete m_pbm;
+  m_pbm = new wxBitmap(bmp);
+
+  // Retrigger the auto timeout
+  if (m_timeout_sec > 0)
+    m_timer_timeout.Start(m_timeout_sec * 1000, wxTIMER_ONE_SHOT);
+}
+
+void TimedPopupWin::OnPaint(wxPaintEvent &event) {
+  int width, height;
+  GetClientSize(&width, &height);
+  wxPaintDC dc(this);
+
+  wxMemoryDC mdc;
+  mdc.SelectObject(*m_pbm);
+  dc.Blit(0, 0, width, height, &mdc, 0, 0);
+}
