@@ -34,18 +34,18 @@
 // ----------------------------------------------------------------------------
 
 // For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 
 //  Why are these not in wx/prec.h?
-#include "wx/dir.h"
-#include "wx/stream.h"
-#include "wx/wfstream.h"
-#include "wx/tokenzr.h"
-#include "wx/filename.h"
+#include <wx/dir.h>
+#include <wx/stream.h>
+#include <wx/wfstream.h>
+#include <wx/tokenzr.h>
+#include <wx/filename.h>
 #include <wx/image.h>
 #include <wx/fileconf.h>
 #include <wx/mstream.h>
@@ -58,9 +58,10 @@
 #include <SQLiteCpp/SQLiteCpp.h>
 
 #include "mbtiles.h"
-#include "chart1.h"
 #include "chcanv.h"
 #include "glChartCanvas.h"
+#include "ocpn_frame.h"
+#include "shaders.h"
 
 //  Missing from MSW include files
 #ifdef _MSC_VER
@@ -84,6 +85,10 @@ class MyConfig;
 extern MyConfig *pConfig;
 #endif
 
+// Raster Zoom Modifier value from advanced display preference pane
+// Physically located in ocpn_app.cpp
+extern int g_chart_zoom_modifier_raster;
+
 #define LON_UNDEF NAN
 #define LAT_UNDEF NAN
 
@@ -132,6 +137,28 @@ static const double OSM_zoomMPP[] = {
 static const double eps = 6e-6;  // about 1cm on earth's surface at equator
 extern MyFrame *gFrame;
 
+// Private tile shader source
+static const GLchar* tile_vertex_shader_source =
+    "attribute vec2 aPos;\n"
+    "attribute vec2 aUV;\n"
+    "uniform mat4 MVMatrix;\n"
+    "varying vec2 varCoord;\n"
+    "void main() {\n"
+    "   gl_Position = MVMatrix * vec4(aPos, 0.0, 1.0);\n"
+    "   varCoord = aUV;\n"
+    "}\n";
+
+static const GLchar* tile_fragment_shader_source =
+    "precision lowp float;\n"
+    "uniform sampler2D uTex;\n"
+    "varying vec2 varCoord;\n"
+    "void main() {\n"
+    "   gl_FragColor = texture2D(uTex, varCoord);\n"
+    "}\n";
+
+
+GLShaderProgram *g_tile_shader_program;
+
 #if defined(__UNIX__) && \
     !defined(__WXOSX__)  // high resolution stopwatch for profiling
 class OCPNStopWatch {
@@ -292,12 +319,7 @@ bool ChartMBTiles::AdjustVP(ViewPort &vp_last, ViewPort &vp_proposed) {
 
 double ChartMBTiles::GetNormalScaleMin(double canvas_scale_factor,
                                        bool b_allow_overzoom) {
-  //      if(b_allow_overzoom)
-  return (canvas_scale_factor / m_ppm_avg) /
-         132;  // allow wide range overzoom overscale
-  //      else
-  //            return (canvas_scale_factor / m_ppm_avg) / 2;         // don't
-  //            suggest too much overscale
+  return (1); //allow essentially unlimited overzoom
 }
 
 double ChartMBTiles::GetNormalScaleMax(double canvas_scale_factor,
@@ -939,7 +961,7 @@ bool ChartMBTiles::RenderTile(mbTileDescriptor *tile, int zoomLevel,
     glDisable(GL_TEXTURE_2D);
     return false;
   } else {
-#ifndef USE_ANDROID_GLES2
+#if !defined(USE_ANDROID_GLES2) && !defined(ocpnUSE_GLSL)
     glColor4f(1,1,1,1);
 #endif
     glEnable(GL_TEXTURE_2D);
@@ -967,7 +989,59 @@ bool ChartMBTiles::RenderTile(mbTileDescriptor *tile, int zoomLevel,
   coords[6] = p.m_x;
   coords[7] = p.m_y;
 
-  glChartCanvas::RenderSingleTexture(coords, texcoords, &vp, 0, 0, 0);
+  if (!g_tile_shader_program) {
+    GLShaderProgram *shaderProgram = new GLShaderProgram;
+    shaderProgram->addShaderFromSource(tile_vertex_shader_source, GL_VERTEX_SHADER);
+    shaderProgram->addShaderFromSource(tile_fragment_shader_source, GL_FRAGMENT_SHADER);
+    shaderProgram->linkProgram();
+    g_tile_shader_program = shaderProgram;
+  }
+
+    GLShaderProgram *shader = g_tile_shader_program;
+    shader->Bind();
+
+   // Set up the texture sampler to texture unit 0
+    shader->SetUniform1i("uTex", 0);
+
+    shader->SetUniformMatrix4fv("MVMatrix", (GLfloat *)vp.vp_matrix_transform);
+
+    float co1[8];
+    float tco1[8];
+
+    shader->SetAttributePointerf("aPos", co1);
+    shader->SetAttributePointerf("aUV", tco1);
+
+    // Perform the actual drawing.
+
+// For some reason, glDrawElements is busted on Android
+// So we do this a hard ugly way, drawing two triangles...
+#if 0
+    GLushort indices1[] = {0,1,3,2};
+    glDrawElements(GL_TRIANGLE_STRIP, 4, GL_UNSIGNED_SHORT, indices1);
+#else
+
+    co1[0] = coords[0];
+    co1[1] = coords[1];
+    co1[2] = coords[2];
+    co1[3] = coords[3];
+    co1[4] = coords[6];
+    co1[5] = coords[7];
+    co1[6] = coords[4];
+    co1[7] = coords[5];
+
+    tco1[0] = texcoords[0];
+    tco1[1] = texcoords[1];
+    tco1[2] = texcoords[2];
+    tco1[3] = texcoords[3];
+    tco1[4] = texcoords[6];
+    tco1[5] = texcoords[7];
+    tco1[6] = texcoords[4];
+    tco1[7] = texcoords[5];
+
+    glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
+#endif
+
+    shader->UnBind();
 
   glDisable(GL_BLEND);
 
@@ -995,15 +1069,16 @@ bool ChartMBTiles::RenderRegionViewOnGL(const wxGLContext &glc,
     LLRegion validRegion = m_minZoomRegion;
     validRegion.Intersect(screenLLRegion);
     glChartCanvas::SetClipRegion(vp, validRegion);
-  } else
+  }
+  else
     glChartCanvas::SetClipRegion(vp, m_minZoomRegion);
 
   /* setup opengl parameters */
   glEnable(GL_TEXTURE_2D);
 
   int viewZoom = m_maxZoom;
-  double zoomMod =
-      2.0;  // decrease to get more detail, nominal 4?, 2 works OK for NOAA.
+  // Set zoom modifier according to Raster Zoom Modifier settings from display preference pane
+  double zoomMod = 2 * pow(2, g_chart_zoom_modifier_raster / 3.0);
 
   for (int kz = m_minZoom; kz <= 19; kz++) {
     double db_mpp = OSM_zoomMPP[kz];
