@@ -26,23 +26,25 @@
  *
  */
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // precompiled headers
 #include "dychart.h"
 
 #include "chcanv.h"
 #include "piano.h"
 #include "chartdb.h"
-#include "chart1.h"
 #include "chartbase.h"
 #include "styles.h"
 #include "ocpndc.h"
 #include "cutil.h"
 #include "wx28compat.h"
 #include "OCPNPlatform.h"
+#include "color_handler.h"
+#include "ocpn_plugin.h"
+#include "ocpn_frame.h"
 
 #ifdef __OCPN__ANDROID__
 #include "qdebug.h"
@@ -66,6 +68,8 @@ extern int g_GUIScaleFactor;
 extern bool g_bopengl;
 
 extern OCPNPlatform *g_Platform;
+extern MyFrame *gFrame;
+extern BasePlatform *g_BasePlatform;
 
 //------------------------------------------------------------------------------
 //          Piano Window Implementation
@@ -77,7 +81,6 @@ END_EVENT_TABLE()
 // Define a constructor
 Piano::Piano(ChartCanvas *parent) {
   m_parentCanvas = parent;
-  ;
 
   m_index_last = -1;
   m_iactive = -1;
@@ -284,9 +287,10 @@ void Piano::BuildGLTexture() {
   dc.SetBrush(tbackBrush);
   dc.DrawRectangle(0, 0, m_texw, m_texh);
 
-  double nominal_line_width_pix =
-      wxMax(1.0, floor(g_Platform->GetDisplayDPmm() /
-                       2.0));  // 0.5 mm nominal, but not less than 1 pixel
+  // 0.5 mm nominal, but not less than 1 pixel
+  double nominal_line_width_pix = floor(g_Platform->GetDisplayDPmm() / 2.0);
+  nominal_line_width_pix *= OCPN_GetWinDIPScaleFactor();
+  nominal_line_width_pix = wxMax(1.0, nominal_line_width_pix);
 
   // draw the needed rectangles
   wxPen ppPen(GetGlobalColor(_T("CHBLK")), nominal_line_width_pix,
@@ -358,8 +362,13 @@ void Piano::BuildGLTexture() {
 }
 
 void Piano::DrawGL(int off) {
+  return DrawGLSL(off);
+}
+void Piano::DrawGLSL(int off) {
 #ifdef ocpnUSE_GL
-  unsigned int w = m_parentCanvas->GetClientSize().x, h = GetHeight(), endx = 0;
+  unsigned int w = m_parentCanvas->GetClientSize().x * m_parentCanvas->GetContentScaleFactor();
+  int h = GetHeight();
+  int endx = 0;
 
   if (m_tex_piano_height != h) BuildGLTexture();
 
@@ -459,33 +468,17 @@ void Piano::DrawGL(int off) {
 
   glBindTexture(GL_TEXTURE_2D, m_tex);
 
-#ifndef USE_ANDROID_GLES2
-  if (style->chartStatusWindowTransparent) {
-    glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-    glColor4ub(255, 255, 255,
-               200);  // perhaps we could allow the style to set this
-    glEnable(GL_BLEND);
-  } else
-    glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
-
   glEnable(GL_TEXTURE_2D);
 
-#ifdef USE_ANDROID_GLES2
   glEnable(GL_BLEND);
-  m_parentCanvas->GetglCanvas()->RenderTextures(coords, texcoords, vc / 2,
-                                                m_parentCanvas->GetpVP());
+  m_parentCanvas->GetglCanvas()->RenderTextures(
+    m_parentCanvas->GetglCanvas()->m_gldc,
+    coords, texcoords, vc / 2, m_parentCanvas->GetpVP());
   glDisable(GL_BLEND);
 
-#else
-  glEnableClientState(GL_VERTEX_ARRAY);
-  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+  glDisable(GL_BLEND);
 
-  glTexCoordPointer(2, GL_FLOAT, 0, texcoords);
-  glVertexPointer(2, GL_FLOAT, 0, coords);
-  glDrawArrays(GL_QUADS, 0, vc / 2);
-
-  // draw the bitmaps
+    // draw the bitmaps
   vc = tc = 0;
   for (int i = 0; i < nKeys; i++) {
     int key_db_index = m_key_array[i];
@@ -536,25 +529,22 @@ void Piano::DrawGL(int off) {
     coords[vc++] = y2;
     texcoords[tc++] = u1, texcoords[tc++] = v2, coords[vc++] = x1,
     coords[vc++] = y2;
-  }
-  glEnable(GL_BLEND);
-  glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
 
-  glTexCoordPointer(2, GL_FLOAT, 0, texcoords);
-  glVertexPointer(2, GL_FLOAT, 0, coords);
-  glDrawArrays(GL_QUADS, 0, vc / 2);
-#endif
+
+    glEnable(GL_TEXTURE_2D);
+    glBindTexture(GL_TEXTURE_2D, m_tex);
+    glEnable(GL_BLEND);
+
+    m_parentCanvas->GetglCanvas()->RenderTextures(
+      m_parentCanvas->GetglCanvas()->m_gldc,
+      coords, texcoords, vc / 2, m_parentCanvas->GetpVP());
+  }
 
   glDisable(GL_BLEND);
-
-#ifndef USE_ANDROID_GLES2
-  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-  glDisableClientState(GL_VERTEX_ARRAY);
-#endif
+  glDisable(GL_TEXTURE_2D);
   delete[] texcoords;
   delete[] coords;
 
-  glDisable(GL_TEXTURE_2D);
 #endif
 }
 
@@ -684,7 +674,12 @@ wxString &Piano::GetStoredHash() { return m_hash; }
 
 void Piano::FormatKeys(void) {
   ocpnStyle::Style *style = g_StyleManager->GetCurrentStyle();
-  int width = m_parentCanvas->GetClientSize().x, height = GetHeight();
+  int width = m_parentCanvas->GetClientSize().x;
+#ifdef __WXOSX__
+  if(g_bopengl)
+    width *= m_parentCanvas->GetContentScaleFactor();
+#endif
+  int height = GetHeight();
   width *= g_btouch ? 0.98f : 0.6f;
 
   int nKeys = m_key_array.size();
@@ -692,7 +687,7 @@ void Piano::FormatKeys(void) {
   if (nKeys) {
     if (!kw) kw = width / nKeys;
 
-    kw = wxMin(kw, (m_parentCanvas->GetClientSize().x * 3 / 4) / nKeys);
+    kw = wxMin(kw, (width * 3 / 4) / nKeys);
     kw = wxMax(kw, 6);
 
     //    Build the Key Regions
@@ -719,8 +714,20 @@ wxPoint Piano::GetKeyOrigin(int key_index) {
 bool Piano::MouseEvent(wxMouseEvent &event) {
   int x, y;
   event.GetPosition(&x, &y);
+#ifdef __WXOSX__
+  if (g_bopengl){
+    x *= OCPN_GetDisplayContentScaleFactor();
+    y *= OCPN_GetDisplayContentScaleFactor();
+  }
+#endif
 
-  if (event.Leaving() || y < m_parentCanvas->GetCanvasHeight() - GetHeight()) {
+  int ytop = m_parentCanvas->GetCanvasHeight() - GetHeight();
+#ifdef __WXOSX__
+  if (!g_bopengl)
+    ytop = m_parentCanvas->GetClientSize().y - GetHeight();
+#endif
+
+  if (event.Leaving() || y < ytop) {
     if (m_bleaving) return false;
     m_bleaving = true;
   } else
@@ -800,7 +807,7 @@ bool Piano::MouseEvent(wxMouseEvent &event) {
    Allows us to get rid of global statics...
 
    wxCommandEvent ev(MyPianoEvent);    // Private event
-   ..set up event to specify action...SelectChart, SetChartThumbnail, etc
+   ..set up event to specify action...SelectChart,  etc
    ::PostEvent(pEventReceiver, ev);    // event receiver passed to ctor
 
    */
@@ -814,7 +821,11 @@ void Piano::ResetRollover(void) {
 }
 
 int Piano::GetHeight() {
-  int height = 22;  // default desktop value
+  int height = 22 ;
+#ifdef __WXOSX__
+  if (g_bopengl)
+    height *= m_parentCanvas->GetContentScaleFactor();
+#endif
   if (g_btouch) {
     double size_mult = exp(g_GUIScaleFactor * 0.0953101798043);  // ln(1.1)
     height *= size_mult;
@@ -827,6 +838,8 @@ int Piano::GetHeight() {
   height = wxMax(height, 4 * g_Platform->GetDisplayDPmm());
 #endif
 
+  height /= g_BasePlatform->GetDisplayDIPMult(gFrame);
+
   return height;
 }
 
